@@ -12,6 +12,7 @@
 #include <string>
 
 #define ARTICLE_SIGN "_ARTICLE_"
+#define BOARD_SIGN "_BOARD_"
 #define RES_SIGN     "_RES_"
 #define NAME_SIGN    "_NAME_"
 #define ID_SIGN      "_ID_"
@@ -38,7 +39,6 @@ namespace ARTICLE
 
         virtual void restore();
         virtual void switch_admin();
-        virtual void set_tabicon( const std::string& url, const std::string& iconname );
 
       private:
         void delete_popup();
