@@ -52,12 +52,18 @@ namespace CONFIG
     // レスを参照するときに前に付ける文字
     const std::string& get_ref_prefix();
 
+    // JD ホームページのアドレス
+    const std::string& get_url_jdhp();
+
     // 2chの認証サーバ
     const std::string& get_url_login2ch();
 
     // bbsmenu.htmlのURL
     const std::string& get_url_bbsmenu();    
 
+    // bbsmenu.html内にあるリンクは全て板とみなす
+    const bool use_link_as_board();
+
     // 2ch にアクセスするときのエージェント名
     const std::string& get_agent_for2ch();
 
@@ -101,6 +107,7 @@ namespace CONFIG
     const int get_loader_timeout();
     const int get_loader_timeout_post();
     const int get_loader_timeout_img();
+    const int get_loader_timeout_checkupdate();
 
     // ipv6使用
     const bool get_use_ipv6();
@@ -130,6 +137,10 @@ namespace CONFIG
     const bool get_use_image_view();
     void set_use_image_view( bool image_view );
 
+    // インライン画像表示をする
+    const bool get_use_inline_image();
+    void set_use_inline_image( bool inline_img );
+
     // 画像にモザイクかける
     const bool get_use_mosaic();
     void set_use_mosaic( bool mosaic );
@@ -142,9 +153,16 @@ namespace CONFIG
     const int get_del_img_day();
     void set_del_img_day( int day );
 
-    // ダウンロードする画像の最大サイズ(Mbyte)
+    // 画像あぼーん削除の日数
+    const int get_del_imgabone_day();
+    void set_del_imgabone_day( int day );
+
+    // ダウンロードする画像の最大ファイルサイズ(Mbyte)
     const int get_max_img_size();
 
+    // 画像の最大サイズ(Mピクセル)
+    const int get_max_img_pixel();
+
     // スレ一覧にdat落ちしたスレも表示する
     const bool get_show_oldarticle();
     void set_show_oldarticle( bool showarticle );
@@ -152,12 +170,18 @@ namespace CONFIG
     // スレ一覧で指定した値(時間)よりも後に立てられたスレを新着とみなす
     const int get_newthread_hour();
 
+    // スレ一覧でインクリメント検索をする
+    const bool get_inc_search_board();
+
     // ツリービューのスクロール量(行数)
     const int get_tree_scroll_size();
 
     // スレビューのスクロール量
     const int get_scroll_size();
 
+    // スレビューのスクロール量(キー上下)
+    const int get_key_scroll_size();
+
     // 板一覧でカテゴリを常にひとつだけ開く
     const bool get_open_one_category();
 
@@ -172,16 +196,26 @@ namespace CONFIG
     // 書き込み中のダイアログを表示しない
     const bool get_hide_writing_dialog();
 
+    // 非アクティブ時に書き込みビューを折りたたむ
+    const bool get_fold_message();
+    void set_fold_message( bool fold );
+
     // ポップアップとカーソルの間のマージン
     const int get_margin_popup();
     void set_margin_popup( int margin );
 
+    // 画像ポップアップとカーソルの間のマージン
+    const int get_margin_imgpopup();
+
     // マウスジェスチャの判定開始半径
     const int get_mouse_radius();
 
     // 履歴の保持数
     const int get_history_size();
 
+    // AA履歴の保持数
+    const int get_aahistory_size();
+
     // 0以上なら多重ポップアップの説明を表示する
     const int get_instruct_popup();
 
@@ -208,6 +242,17 @@ namespace CONFIG
     const bool get_strict_char_width();
     void set_strict_char_width( bool strictwidth );
 
+    // スレビューで発言数(ID)をカウントする
+    const bool get_check_id();
+
+    // レス参照で色を変える回数
+    const int get_num_reference_high();
+    const int get_num_reference_low();
+
+    // 発言数で色を変える回数
+    const int get_num_id_high();
+    const int get_num_id_low();
+
     // datのパース時にURL判定を甘くする(^なども含める)
     const bool get_loose_url();
 
@@ -217,6 +262,9 @@ namespace CONFIG
     // 指定した数よりもユーザーコマンドが多い場合はサブメニュー化する
     const int get_max_show_usrcmd();
 
+    // スレビューで再読み込みボタンを押したときに全タブを更新する
+    const bool get_reload_allthreads();
+
     // タブに表示する文字列の最小値
     const int get_tab_min_str();
 
@@ -230,6 +278,12 @@ namespace CONFIG
     void set_list_abone_word_thread( std::list< std::string >& word );
     void set_list_abone_regex_thread( std::list< std::string >& regex );
 
+    const int get_abone_number_thread();
+    void set_abone_number_thread( const int number );
+
+    const int get_abone_hour_thread();
+    void set_abone_hour_thread( const int hour );
+
     // articleviewでのレスの全体あぼーん
     std::list< std::string >& get_list_abone_name(); // 名前
     std::list< std::string >& get_list_abone_word(); // ワード
@@ -245,6 +299,14 @@ namespace CONFIG
 
     const bool get_abone_chain();
     void set_abone_chain( bool set );
+
+    // 右ペーンが空の時にサイドバーを閉じるか
+    const bool get_expand_sidebar();
+
+#ifdef HAVE_MIGEMO_H
+    // migemo-dictの場所
+    const std::string& get_migemodict_path();
+#endif
 }
 
 
