@@ -88,7 +88,6 @@ namespace CORE
         Gtk::HBox m_toolbar_hbox;
         Gtk::Entry m_entry_url;
         SKELETON::ImgButton m_button_go;
-        SKELETON::ImgButton m_button_search_cache;
         SKELETON::ImgToggleButton m_button_bbslist;
         SKELETON::ImgToggleButton m_button_favorite;
         SKELETON::ImgToggleButton m_button_board;
@@ -178,29 +177,38 @@ namespace CORE
         void slot_setup_fontcolor();
         void slot_setup_proxy();
         void slot_setup_passwd();
+        void slot_setup_boarditem();
+        void slot_board_pref();
+        void slot_article_pref();
+        void slot_image_pref();
         void slot_setup_browser();
         void slot_setup_abone();
         void slot_setup_abone_thread();
         void slot_toggle_abone_transp_chain();
 
-        void slot_show_hp();
         void slot_show_bbs();
         void slot_show_old2ch();
         void slot_show_manual();
         void slot_show_about();
         void slot_quit();
         void slot_reload_list();
+        void slot_check_update_root();
+        void slot_check_update_open_root();
+        void slot_cancel_check_update();
         void slot_save_favorite();
         void slot_toggle_online();
         void slot_toggle_login2ch();
         void toggle_menubar();
         void toggle_sidebar();
+        void slot_search_cache_board();
         void slot_search_cache();
         void slot_show_hide_leftpane( int mode );
         void slot_toggle_toolbarpos( int pos );
         void slot_toggle_toolbarbbslist();
         void slot_toggle_toolbararticle();
         void slot_toggle_toolbarboard();
+        void slot_toggle_tabboard();
+        void slot_toggle_tabarticle();
         void slot_toggle_2pane();
         void slot_toggle_3pane();
         void slot_toggle_v3pane();
@@ -212,6 +220,7 @@ namespace CORE
         void slot_shortmargin_popup();
         void slot_toggle_emacsmode();
         void slot_toggle_restore_views();
+        void slot_toggle_fold_message();
 
         virtual void callback_dispatch();
 
@@ -238,7 +247,6 @@ namespace CORE
 
         bool slot_focus_out_event( GdkEventFocus* ev );
         bool slot_focus_in_event( GdkEventFocus* ev );
-        bool slot_window_state_event( GdkEventWindowState* event );
         void slot_active_url();
 
         // あるadminがemptyになったので他のadminにスイッチ
