@@ -1,4 +1,4 @@
-// ライセンス: 最新のGPL
+// ライセンス: GPL2
 
 // 画像データベースのルートクラス
 
@@ -6,7 +6,7 @@
 #define _IMGROOT_H
 
 #include <string>
-#include <list>
+#include <map>
 
 namespace DBIMG
 {
@@ -14,7 +14,7 @@ namespace DBIMG
 
     class ImgRoot
     {
-        std::list< Img* > m_list_img;
+        std::map< std::string, Img* > m_map_img;
         
       public:
         ImgRoot();
@@ -30,11 +30,19 @@ namespace DBIMG
         bool is_loadable( const std::string& url );
         bool is_loadable( const char* url, int n );
 
+        bool is_jpg( const char* url, int n );
+        bool is_png( const char* url, int n );
+        bool is_gif( const char* url, int n );
+
         // キャッシュ削除
-        void delete_cache( const std::string& url, bool redraw );
+        void delete_cache( const std::string& url );
 
         // 全キャッシュ削除
         void delete_all_files();
+
+      private:
+        void redraw_imgs();
+        void reset_imgs();
     };
 }
 
