@@ -1,4 +1,4 @@
-// ライセンス: 最新のGPL
+// ライセンス: GPL2
 
 //#define _DEBUG
 #include "jddebug.h"
@@ -6,6 +6,9 @@
 #include "root.h"
 #include "boardbase.h"
 #include "articlebase.h"
+#include "interface.h"
+
+#include "skeleton/msgdiag.h"
 
 #include "jdlib/jdiconv.h"
 #include "jdlib/jdregex.h"
@@ -36,13 +39,17 @@ BoardBase::BoardBase( const std::string& root, const std::string& path_board, co
     , m_root( root )
     , m_path_board( path_board )
     , m_name( name )
+    , m_samba_sec( 0 )
     , m_rawdata( 0 )
     , m_read_info( 0 )
+    , m_append_articles( false )
     , m_article_null( 0 )
 {
     clear();
     clear_load_data();
 
+    memset( &m_write_time, 0, sizeof( struct timeval ) );
+
     // 板情報はクラスが作られた時点ではまだ読まない
     // BoardBase::read_info() の説明を見ること
 }
@@ -79,19 +86,6 @@ bool BoardBase::empty()
 }
 
 
-void BoardBase::set_view_sort_column( int column )
-{
-    m_view_sort_column = column;
-}
-
-
-void BoardBase::set_view_sort_ascend( bool ascend )
-{
-    m_view_sort_ascend = ascend;
-}
-
-
-
 void BoardBase::set_check_noname( bool check )
 {
     m_check_noname = check;
@@ -120,24 +114,53 @@ const std::string& BoardBase::get_agent()
 // プロキシ
 const std::string BoardBase::get_proxy_host()
 {
-    if( ! CONFIG::get_use_proxy_for_data() ) return std::string();
-    return CONFIG::get_proxy_for_data();
+    int mode = get_mode_local_proxy();
+
+    if( mode == DBTREE::PROXY_GLOBAL ){
+
+        if( CONFIG::get_use_proxy_for_data() ) return CONFIG::get_proxy_for_data();
+    }
+    else if( mode == DBTREE::PROXY_LOCAL ) return get_local_proxy();
+
+    return std::string();
 }
 
 const int BoardBase::get_proxy_port()
 {
-    return CONFIG::get_proxy_port_for_data();
+    int mode = get_mode_local_proxy();
+
+    if( mode == DBTREE::PROXY_GLOBAL ) return CONFIG::get_proxy_port_for_data();
+    else if( mode == DBTREE::PROXY_LOCAL ) return get_local_proxy_port();
+
+    return 0;
 }
 
 // 書き込み用プロキシ
 const std::string BoardBase::get_proxy_host_w()
 {
-    return get_proxy_host();
+    int mode = get_mode_local_proxy_w();
+
+    if( mode == DBTREE::PROXY_GLOBAL ) return get_proxy_host();
+    else if( mode == DBTREE::PROXY_LOCAL ) return get_local_proxy_w();
+
+    return std::string();
 }
 
 const int BoardBase::get_proxy_port_w()
 {
-    return get_proxy_port();
+    int mode = get_mode_local_proxy_w();
+
+    if( mode == DBTREE::PROXY_GLOBAL ) return get_proxy_port();
+    else if( mode == DBTREE::PROXY_LOCAL ) return get_local_proxy_port_w();
+
+    return 0;
+}
+
+
+// ローカルルール
+const std::string BoardBase::localrule()
+{
+    return "利用できません";
 }
 
 
@@ -198,6 +221,53 @@ ArticleBase* BoardBase::append_article( const std::string& id, bool cached )
 }
 
 
+//
+// 書き込み時間更新
+//
+void BoardBase::update_writetime()
+{
+    struct timeval tv;
+    struct timezone tz;
+    if( gettimeofday( &tv, &tz ) == 0 ){
+
+        m_write_time = tv;
+
+#ifdef _DEBUG
+        std::cout << "BoardBase::update_writetime : " << m_write_time.tv_sec << std::endl;
+#endif
+    }
+}
+
+
+//
+// 経過時間(秒)
+//
+const time_t BoardBase::get_write_pass()
+{
+    time_t ret = 0;
+    struct timeval tv;
+    struct timezone tz;
+
+    if( m_write_time.tv_sec && gettimeofday( &tv, &tz ) == 0 ) ret = MAX( 0, tv.tv_sec - m_write_time.tv_sec );
+
+    return ret;
+}
+
+
+//
+// 書き込み可能までの残り秒
+//
+time_t BoardBase::get_write_leftsec()
+{
+    const time_t mrg = 2;
+
+    if( ! m_samba_sec ) return 0;
+    if( ! get_write_pass() ) return 0;
+
+    return MAX( 0, m_samba_sec + mrg - get_write_pass() );
+}
+
+
 
 //
 // 板情報の取得
@@ -220,11 +290,8 @@ void BoardBase::read_info()
         // 板の情報ファイル読み込み
         read_board_info();
 
-        // キャッシュにあるレスをデータベースに登録
-        append_all_article_in_cache();
-
-        // キャッシュからSETTING.TXT のロード
-        load_setting();
+        // キャッシュからローカルルールとSETTING.TXT のロード
+        load_rule_setting();
     }
 }
 
@@ -239,7 +306,7 @@ void BoardBase::update_root( const std::string& root )
 
     // 配下の ArticleBase にも知らせてあげる
     std::list< ArticleBase* >::iterator it;
-    for( it = m_list_article.begin(); it != m_list_article.end(); ++it ) ( *it )->update_url( url_datbase() );
+    for( it = m_list_article.begin(); it != m_list_article.end(); ++it ) ( *it )->update_datbase( url_datbase() );
 }
 
 
@@ -503,6 +570,9 @@ ArticleBase* BoardBase::get_article( const std::string id )
 {
     if( id.empty() ) return get_article_null();
 
+    // キャッシュにあるレスをデータベースに登録
+    append_all_article_in_cache();
+
     // 線形リストなので遅い
     // TODO : ハッシュにする
     std::list< ArticleBase* >::iterator it;
@@ -543,7 +613,7 @@ ArticleBase* BoardBase::get_article_create( const std::string id )
 
         // データベースに無いので新規登録
         //
-        // なおRoot::get_board()　経由で呼ばれる BoardBase::read_info() でキャッシュにある
+        // なおget_article()でキャッシュにある
         // スレは全てDBに登録されているので DBに無いということはキャッシュにも無いということ。
         // よって append_article()に  cached = false　をパラメータとして渡す
 
@@ -614,7 +684,7 @@ ArticleBase* BoardBase::get_article_fromURL( const std::string url )
 void BoardBase::download_subject()
 {
 #ifdef _DEBUG
-    std::cout << "BoardBase::download_subject() " << url_boardbase() << std::endl;
+    std::cout << "BoardBase::download_subject " << url_subject() << std::endl;
 #endif
 
     if( empty() ) return;
@@ -622,6 +692,8 @@ void BoardBase::download_subject()
 
     clear();
     m_rawdata = ( char* )malloc( SIZE_OF_RAWDATA );
+    m_read_url_boardbase = false;
+    m_load_rule_setting = false;
 
     // オフライン
     if( ! SESSION::is_online() ){
@@ -635,9 +707,11 @@ void BoardBase::download_subject()
 
     // オンライン
 
+    m_load_rule_setting = true;
+
     // subject.txtのキャッシュが無かったら modified をリセット
-    std::string path_subject = CACHE::path_board_root( url_boardbase() ) + m_subjecttxt;
-    if( CACHE::is_file_exists( path_subject ) != CACHE::EXIST_FILE ) set_date_modified( std::string() );
+    std::string path_subject = CACHE::path_board_root_fast( url_boardbase() ) + m_subjecttxt;
+    if( CACHE::file_exists( path_subject ) != CACHE::EXIST_FILE ) set_date_modified( std::string() );
 
     JDLIB::LOADERDATA data;    
     create_loaderdata( data );
@@ -680,36 +754,81 @@ void BoardBase::receive_data( const char* data, size_t size )
 //
 void BoardBase::receive_finish()
 {
-    // 別スレッドでSETTING.TXT のダウンロード開始
-    download_setting();
+    // 別スレッドでローカルルールとSETTING.TXT のダウンロード開始
+    if( m_load_rule_setting ) download_rule_setting();
+
+    m_list_subject.clear();
 
     bool read_from_cache = false;
-    std::string path_subject = CACHE::path_board_root( url_boardbase() ) + m_subjecttxt;
-    std::string path_oldsubject = CACHE::path_board_root( url_boardbase() ) + "old-" + m_subjecttxt;
+    std::string path_subject = CACHE::path_board_root_fast( url_boardbase() ) + m_subjecttxt;
+    std::string path_oldsubject = CACHE::path_board_root_fast( url_boardbase() ) + "old-" + m_subjecttxt;
 
 #ifdef _DEBUG
-    std::cout << "BoardBase::receive_finish code = " << get_str_code() << std::endl;
+    std::cout << "----------------------------------\nBoardBase::receive_finish code = " << get_str_code() << std::endl;
+    std::cout << "size = " << m_lng_rawdata << std::endl;
 #endif
 
-    // エラー or 移転
-    if( get_code() != HTTP_ERR
+    // 移転チェック
+    if( m_read_url_boardbase ){
+
+#ifdef _DEBUG
+        std::cout << "move check\n";
+#endif
+        m_rawdata[ m_lng_rawdata ] = '\0';
+        set_date_modified( std::string() );
+        CORE::core_set_command( "update_board", url_subject() );
+
+        if( get_code() == HTTP_OK && std::string( m_rawdata ).find( "window.location.href" ) != std::string::npos ){
+
+#ifdef _DEBUG
+            std::cout << m_rawdata << std::endl;
+#endif
+            JDLIB::Regex regex;
+            std::string query = ".*window.location.href=\"([^\"]*)\".*";
+            if( regex.exec( query, m_rawdata ) ){
+
+                std::string new_url = regex.str( 1 );
+                std::string msg = new_url + " に移転しました。\n\nデータベースを更新しますか？";
+
+                SKELETON::MsgDiag mdiag( NULL, msg, false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
+                mdiag.set_default_response( Gtk::RESPONSE_OK );
+                if( mdiag.run() == Gtk::RESPONSE_OK ){
+
+                    DBTREE::update_board( new_url, get_name() );
+                    CORE::core_set_command( "open_board", url_subject() );
+                }
+            }
+        }
+
+        clear();
+        return;
+    }
+
+    // サーバーからtimeoutなどのエラーが返った or 移転
+    if( get_code() != HTTP_ERR // HTTP_ERR はローダでの内部のエラー
         && get_code() != HTTP_OK
         && get_code() != HTTP_NOT_MODIFIED ){
 
         m_lng_rawdata = 0;
 
-        // 移転した場合
+        // 移転した場合bbsmenuを更新
         if( get_code() == HTTP_REDIRECT ){
 
-            Gtk::MessageDialog mdiag( "移転しました\n\n板リストを更新しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
+            SKELETON::MsgDiag mdiag( NULL, "移転しました\n\n板リストを更新しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
+            mdiag.set_default_response( Gtk::RESPONSE_OK );
             if( mdiag.run() == Gtk::RESPONSE_OK ) CORE::core_set_command( "reload_bbsmenu" );
+
+            set_date_modified( std::string() );
+            CORE::core_set_command( "update_board", url_subject() );
+            clear();
+            return;
         }
 
-        // エラー
-        else read_from_cache = true;
+        // サーバからエラーが返ったらキャッシュからデータをロード
+        read_from_cache = true;
     }
 
-    // not modified か offline ならキャッシュからデータをロード
+    // ローダがエラーを返した or not modified or offline ならキャッシュからデータをロード
     if( get_code() == HTTP_ERR
         || get_code() == HTTP_NOT_MODIFIED
         || ! SESSION::is_online() ) read_from_cache = true;
@@ -720,43 +839,45 @@ void BoardBase::receive_finish()
         m_lng_rawdata = CACHE::load_rawdata( path_subject, m_rawdata, SIZE_OF_RAWDATA );
 
 #ifdef _DEBUG
-        std::cout << "BoardBase::receive_finish read cache " << path_subject << std::endl;
-        std::cout << "size = " << m_lng_rawdata << std::endl;
+        std::cout << "read from cache " << path_subject << std::endl;
 #endif
     }
 
+#ifdef _DEBUG
+        std::cout << "size(final) = " << m_lng_rawdata << std::endl;
+#endif
+
+    // データが無い
     if( m_lng_rawdata == 0 ){
 
+        set_date_modified( std::string() );
+
+        // 移転した可能性があるので url_boardbase をロードして解析
+        if( SESSION::is_online() && get_code() == HTTP_OK ){
+
+#ifdef _DEBUG
+            std::cout << "reload " << url_boardbase() << std::endl;
+#endif
+            JDLIB::LOADERDATA data;    
+            data.url = url_boardbase();
+            data.agent = CONFIG::get_agent_for_data();
+            if( CONFIG::get_use_proxy_for_data() ) data.host_proxy = CONFIG::get_proxy_for_data();
+            else data.host_proxy = std::string();
+            data.port_proxy = CONFIG::get_proxy_port_for_data();
+            data.size_buf = CONFIG::get_loader_bufsize();
+            data.timeout = CONFIG::get_loader_timeout_img();
+
+            if( start_load( data ) ){
+                m_read_url_boardbase = true;
+                return;
+            }
+        }
+
         CORE::core_set_command( "update_board", url_subject() );
         clear();
         return;
     }
 
-    // codeが200なら情報を保存して subject.txt をキャッシュに保存
-    if( SESSION::is_online() && get_code() == HTTP_OK ){
-
-#ifdef _DEBUG
-        std::cout << "rename " << path_subject << " " << path_oldsubject << std::endl;
-        std::cout << "save " << path_subject << std::endl;    
-#endif
-
-        save_info();
-
-        // subject.txtをキャッシュ
-        if( CACHE::mkdir_boardroot( url_boardbase() ) ){
-
-            // 古いファイルをrename
-            if( CACHE::is_file_exists( path_subject ) == CACHE::EXIST_FILE ){
-                if( rename( path_subject.c_str(), path_oldsubject.c_str() ) != 0 ){
-                    MISC::ERRMSG( "rename failed " + path_subject );
-                }
-            }
-
-            // subject.txt セーブ
-            CACHE::save_rawdata( path_subject, m_rawdata, m_lng_rawdata );
-        }
-    }
-
     // UTF-8に変換しておく
     JDLIB::Iconv* libiconv = new JDLIB::Iconv( m_charset, "UTF-8" );
     int byte_out;
@@ -767,8 +888,6 @@ void BoardBase::receive_finish()
     // データベース更新
     // subject.txtを解析して現行スレだけリスト(m_list_subject)に加える
 
-    m_list_subject.clear();
-
     // 一度全てのarticleをdat落ち状態にして subject.txt に
     // 含まれているものだけ parse_subject()の中で通常状態にする
     std::list< ArticleBase* >::iterator it;
@@ -783,39 +902,84 @@ void BoardBase::receive_finish()
     // subject.txtをパースしながらデータベース更新
     parse_subject( rawdata_utf8 );
 
-    // DAT落ちなどでsubject.txtに無いスレもリストに加える
-    // サブジェクトやロード数などの情報が無いのでスレのinfoファイルから
-    // 取得する必要がある
-    if( CONFIG::get_show_oldarticle() ){
-        for( it = m_list_article.begin(); it != m_list_article.end(); ++it ){
+    // list_subject 更新
+    if( ! m_list_subject.empty() ){
 
-            if( ( *it )->is_cached()
-                && ( ( *it )->get_status() & STATUS_OLD )
-                ){
-
-                // info 読み込み
-                // TODO : 数が多いとboardビューを開くまで時間がかかるのをなんとかする
 #ifdef _DEBUG
-                std::cout << "read article_info << " << ( *it )->get_url() << std::endl;
+        std::cout << "list_subject was updated\n";
+#endif
+
+        // DAT落ちなどでsubject.txtに無いスレもリストに加える
+        // サブジェクトやロード数などの情報が無いのでスレのinfoファイルから
+        // 取得する必要がある
+        if( CONFIG::get_show_oldarticle() ){
+
+            for( it = m_list_article.begin(); it != m_list_article.end(); ++it ){
+
+                if( ( *it )->is_cached()
+                    && ( ( *it )->get_status() & STATUS_OLD )
+                    ){
+
+                    // info 読み込み
+                    // TODO : 数が多いとboardビューを開くまで時間がかかるのをなんとかする
+#ifdef _DEBUG
+                    std::cout << "read article_info << " << ( *it )->get_url() << std::endl;
 #endif                
-                ( *it )->read_info();
+                    ( *it )->read_info();
 
-                // read_info()で状態が変わる時があるのでDAT落ちにしてからリスト(m_list_subject)に加える
-                int status = ( *it )->get_status();
+                    // read_info()で状態が変わる時があるのでDAT落ちにしてからリスト(m_list_subject)に加える
+                    int status = ( *it )->get_status();
 
-                if( status & STATUS_NORMAL ){
-                    status &= ~STATUS_NORMAL;
-                    status |= STATUS_OLD;
-                    ( *it )->set_status( status );
-                    ( *it )->save_info( true );
+                    if( status & STATUS_NORMAL ){
+                        status &= ~STATUS_NORMAL;
+                        status |= STATUS_OLD;
+                        ( *it )->set_status( status );
+                        ( *it )->save_info( true );
+                    }
+
+                    if( ! is_abone_thread( *it ) ) m_list_subject.push_back( *it );
                 }
-
-                if( ! get_abone_thread( *it ) ) m_list_subject.push_back( *it );
             }
         }
+
+        // オンライン、かつcodeが200なら情報を保存して subject.txt をキャッシュに保存
+        if( SESSION::is_online() && get_code() == HTTP_OK ){
+
+#ifdef _DEBUG
+            std::cout << "save info and subject.txt\n";
+            std::cout << "rename " << path_subject << " " << path_oldsubject << std::endl;
+            std::cout << "save " << path_subject << std::endl;    
+#endif
+
+            save_info();
+
+            // subject.txtをキャッシュ
+            if( CACHE::mkdir_boardroot( url_boardbase() ) ){
+
+                // 古いファイルをrename
+                if( CACHE::file_exists( path_subject ) == CACHE::EXIST_FILE ){
+                    if( rename( path_subject.c_str(), path_oldsubject.c_str() ) != 0 ){
+                        MISC::ERRMSG( "rename failed " + path_subject );
+                    }
+                }
+
+                // subject.txt セーブ
+                CACHE::save_rawdata( path_subject, m_rawdata, m_lng_rawdata );
+            }
+        }
+
+        m_list_subject_created = true;
     }
 
-    m_list_subject_created = true;
+    // list_subject が更新されなかった
+    else{
+
+#ifdef _DEBUG
+        std::cout << "list_subject was NOT updated\n";
+#endif
+
+        set_date_modified( std::string() );
+    }
 
     // コアにデータベース更新を知らせる
     CORE::core_set_command( "update_board", url_subject() );
@@ -826,6 +990,31 @@ void BoardBase::receive_finish()
 
 
 
+//
+// キャッシュのディレクトリ内にあるスレのファイル名のリストを取得
+//
+std::list< std::string > BoardBase::get_filelist_in_cache()
+{
+    std::list< std::string >list_out;
+    if( empty() ) return list_out;
+
+    std::list< std::string >list_file;
+    std::string path_board_root = CACHE::path_board_root_fast( url_boardbase() );
+
+    list_file = CACHE::get_filelist( path_board_root );
+    if( ! list_file.size() ) return list_out;
+
+    std::list< std::string >::iterator it = list_file.begin();
+    for(; it != list_file.end(); ++it ){
+
+        std::string& file = ( *it );
+        if( is_valid( file ) ) list_out.push_back( file );
+    }
+
+    return list_out;
+}
+
+
 //
 // キャッシュのディレクトリ内にあるスレのファイル名を取得してDBにすべてを登録
 //
@@ -836,30 +1025,28 @@ void BoardBase::receive_finish()
 //
 void BoardBase::append_all_article_in_cache()
 {
+    if( m_append_articles ) return;
+    m_append_articles = true;
+
 #ifdef _DEBUG
     std::cout << "BoardBase::append_all_article_in_cache\n";
 #endif
     
-    std::list< std::string >list_file;
-    std::string path_board_root = CACHE::path_board_root( url_boardbase() );
-    list_file = CACHE::get_filelist( path_board_root );
+    std::list< std::string >list_file = get_filelist_in_cache();
 
     std::list< std::string >::iterator it = list_file.begin();
     for(; it != list_file.end(); ++it ){
 
-        std::string& file = ( *it );
-        if( is_valid( file ) ){
-
 #ifdef _DEBUG
-            std::cout << "append id = " << file << std::endl;
+        std::cout << "append id = " << ( *it ) << std::endl;
 #endif
-            // キャッシュあり( cached = true ) 指定でDBに登録
-            // キャッシュに無いスレはsubject.txtを読み込んだ時に
-            // 派生クラスのparse_subject()で登録する。
-            append_article( file,
-                            true  // キャッシュあり
-                );
-        }
+
+        // キャッシュあり( cached = true ) 指定でDBに登録
+        // キャッシュに無いスレはsubject.txtを読み込んだ時に
+        // 派生クラスのparse_subject()で登録する。
+        append_article( ( *it ),
+                        true  // キャッシュあり
+            );
     }
 }
 
@@ -880,19 +1067,28 @@ void BoardBase::update_abone_all_article()
 //
 // スレあぼーん判定
 //
-const bool BoardBase::get_abone_thread( ArticleBase* article )
+const bool BoardBase::is_abone_thread( ArticleBase* article )
 {
     if( ! article ) return false;
+    if( article->empty() ) return false;
 
-    bool check_thread = ! m_list_abone_thread.empty();
-    bool check_word = ! m_list_abone_word_thread.empty();
-    bool check_regex = ! m_list_abone_regex_thread.empty();
-    bool check_word_global = ! CONFIG::get_list_abone_word_thread().empty();
-    bool check_regex_global = ! CONFIG::get_list_abone_regex_thread().empty();
+    const int check_number = article->get_number_load() ? 0: ( m_abone_number_thread ? m_abone_number_thread : get_abone_number_global() );
+    const int check_hour = article->get_number_load() ? 0: ( m_abone_hour_thread ? m_abone_hour_thread : CONFIG::get_abone_hour_thread() );
+    const bool check_thread = ! m_list_abone_thread.empty();
+    const bool check_word = ! m_list_abone_word_thread.empty();
+    const bool check_regex = ! m_list_abone_regex_thread.empty();
+    const bool check_word_global = ! CONFIG::get_list_abone_word_thread().empty();
+    const bool check_regex_global = ! CONFIG::get_list_abone_regex_thread().empty();
 
-    if( !check_thread && !check_word && !check_regex && !check_word_global && !check_regex_global ) return false;
+    if( !check_number && !check_hour && !check_thread && !check_word && !check_regex && !check_word_global && !check_regex_global ) return false;
 
     JDLIB::Regex regex;
+
+    // レスの数であぼーん
+    if( check_number ) if( article->get_number() >= check_number ) return true;
+
+    // スレ立てからの時間であぼーん
+    if( check_hour ) if( article->get_hour() >= check_hour ) return true;
     
     // スレあぼーん
     if( check_thread ){
@@ -960,11 +1156,75 @@ void BoardBase::update_abone_thread()
 
 
 
+//
+// あぼーん状態のリセット(情報セットと状態更新を同時におこなう)
+//
+void BoardBase::reset_abone( std::list< std::string >& ids, std::list< std::string >& names, std::list< std::string >& words, std::list< std::string >& regexs )
+{
+    if( empty() ) return;
+
+    // 前後の空白と空白行を除く
+
+    m_list_abone_id = MISC::remove_space_from_list( ids );
+    m_list_abone_id = MISC::remove_nullline_from_list( m_list_abone_id );
+
+    m_list_abone_name = MISC::remove_space_from_list( names );
+    m_list_abone_name = MISC::remove_nullline_from_list( m_list_abone_name );
+
+    m_list_abone_word = MISC::remove_space_from_list( words );
+    m_list_abone_word = MISC::remove_nullline_from_list( m_list_abone_word );
+
+    m_list_abone_regex = MISC::remove_space_from_list( regexs );
+    m_list_abone_regex = MISC::remove_nullline_from_list( m_list_abone_regex );
+
+    update_abone_all_article();
+    CORE::core_set_command( "relayout_all_article" );
+}
+
+
+// あぼ〜ん状態更新(reset_abone()と違って各項目ごと個別におこなう)
+void BoardBase::add_abone_id( const std::string& id )
+{
+    if( empty() ) return;
+    if( id.empty() ) return;
+
+    std::string id_tmp = id.substr( strlen( PROTO_ID ) );
+
+    m_list_abone_id.push_back( id_tmp );
+
+    update_abone_all_article();
+    CORE::core_set_command( "relayout_all_article" );
+}
+
+void BoardBase::add_abone_name( const std::string& name )
+{
+    if( empty() ) return;
+    if( name.empty() ) return;
+
+    m_list_abone_name.push_back( name );
+
+    update_abone_all_article();
+    CORE::core_set_command( "relayout_all_article" );
+}
+
+void BoardBase::add_abone_word( const std::string& word )
+{
+    if( empty() ) return;
+    if( word.empty() ) return;
+
+    m_list_abone_word.push_back( word );
+
+    update_abone_all_article();
+    CORE::core_set_command( "relayout_all_article" );
+}
+
+
 //
 // あぼーん状態のリセット(情報セットと状態更新を同時におこなう)
 //
 void BoardBase::reset_abone_thread( std::list< std::string >& threads,
-                                    std::list< std::string >& words, std::list< std::string >& regexs )
+                                    std::list< std::string >& words, std::list< std::string >& regexs,
+                                    const int number, const int hour )
 {
     if( empty() ) return;
 
@@ -983,10 +1243,83 @@ void BoardBase::reset_abone_thread( std::list< std::string >& threads,
     m_list_abone_regex_thread = MISC::remove_space_from_list( regexs );
     m_list_abone_regex_thread = MISC::remove_nullline_from_list( m_list_abone_regex_thread );
 
+    m_abone_number_thread = number;
+    m_abone_hour_thread = hour;
+
     update_abone_thread();
 }
 
 
+//
+// キャッシュ内のログ検索
+//
+// datファイルのURL(read.cgi型)を返す
+//
+std::list< std::string > BoardBase::search_cache( const std::string& query,
+                                                  bool mode_or, // 今のところ無視
+                                                  bool& stop // 呼出元のスレッドで true にセットすると検索を停止する
+    )
+{
+#ifdef _DEBUG
+    std::cout << "BoardBase::search_cache " << query << std::endl;
+#endif
+
+    std::list< std::string >list_out;
+
+    if( empty() ) return list_out;
+
+    // キャッシュにあるレスをデータベースに登録
+    if( m_list_article.size() == 0 ) append_all_article_in_cache();
+    if( m_list_article.size() == 0 ) return list_out;
+
+    std::string query_local = MISC::Iconv( query, "UTF-8", get_charset() );
+    std::list< std::string > list_query = MISC::split_line( query_local );
+
+    std::string path_board_root = CACHE::path_board_root_fast( url_boardbase() );
+
+    std::list< ArticleBase* >::iterator it;
+    for( it = m_list_article.begin(); it != m_list_article.end(); ++it ){
+
+        ArticleBase* article = ( *it );
+        if( ! article->is_cached() ) continue;
+
+        std::string path = path_board_root + article->get_id();
+        std::string rawdata;
+
+        if( CACHE::load_rawdata( path, rawdata ) > 0 ){
+
+            bool apnd = true;
+
+#ifdef _DEBUG
+            std::cout << "load " << path << " size = " << rawdata.size() << " byte" << std::endl;
+#endif
+
+            std::list< std::string >::iterator it_query = list_query.begin();
+            for( ; it_query != list_query.end(); ++it_query ){
+
+                if( rawdata.find( *it_query ) == std::string::npos ){
+                    apnd = false;
+                    break;
+                }
+            }
+
+            if( apnd ){
+#ifdef _DEBUG
+                std::cout << "found word in " << url_readcgi( article->get_url(), 0, 0 ) << std::endl
+                          << article->get_subject() << std::endl;
+#endif
+                std::string readcgi = url_readcgi( article->get_url(), 0, 0 );
+                list_out.push_back( readcgi );
+            }
+        }
+
+        if( stop ) break;
+    }
+
+    return list_out;
+}
+
+
 
 
 //
@@ -995,25 +1328,49 @@ void BoardBase::reset_abone_thread( std::list< std::string >& threads,
 //
 void BoardBase::read_board_info()
 {
-#ifdef _DEBUG
-    std::cout << "BoardBase::read_board_info " << m_id << std::endl;
-#endif    
-
     if( empty() ) return;
     
     std::string path_info = CACHE::path_jdboard_info( url_boardbase() );
 
+#ifdef _DEBUG
+    std::cout << "BoardBase::read_board_info " << path_info << std::endl;
+#endif    
+
     JDLIB::ConfLoader cf( path_info, std::string() );
 
     std::string modified = cf.get_option( "modified", "" );
     set_date_modified( modified );
 
+    m_modified_localrule = cf.get_option( "modified_localrule", "" );
+    m_modified_setting = cf.get_option( "modified_setting", "" );
+
     m_view_sort_column = cf.get_option( "view_sort_column", -1 );
-    m_view_sort_ascend = cf.get_option( "view_sort_ascend", false );
+    m_view_sort_mode = cf.get_option( "view_sort_mode", 0 );
+    m_view_sort_pre_column = cf.get_option( "view_sort_pre_column", -1 );
+    m_view_sort_pre_mode = cf.get_option( "view_sort_pre_mode", 0 );
+
     m_check_noname = cf.get_option( "check_noname", false );
 
+    std::string str_tmp;
+
+    // あぼーん id は再起動ごとにリセット
+//    str_tmp = cf.get_option( "aboneid", "" );
+//    if( ! str_tmp.empty() ) m_list_abone_id = MISC::strtolist( str_tmp );
+
+    // あぼーん name
+    str_tmp = cf.get_option( "abonename", "" );
+    if( ! str_tmp.empty() ) m_list_abone_name = MISC::strtolist( str_tmp );
+
+    // あぼーん word
+    str_tmp = cf.get_option( "aboneword", "" );
+    if( ! str_tmp.empty() ) m_list_abone_word = MISC::strtolist( str_tmp );
+
+    // あぼーん regex
+    str_tmp = cf.get_option( "aboneregex", "" );
+    if( ! str_tmp.empty() ) m_list_abone_regex = MISC::strtolist( str_tmp );
+
     // スレ あぼーん
-    std::string str_tmp = cf.get_option( "abonethread", "" );
+    str_tmp = cf.get_option( "abonethread", "" );
     if( ! str_tmp.empty() ) m_list_abone_thread = MISC::strtolist( str_tmp );
 
     // スレ あぼーん word
@@ -1024,6 +1381,28 @@ void BoardBase::read_board_info()
     str_tmp = cf.get_option( "aboneregexthread", "" );
     if( ! str_tmp.empty() ) m_list_abone_regex_thread = MISC::strtolist( str_tmp );
 
+    // レス数であぼーん
+    m_abone_number_thread = cf.get_option( "abonenumberthread", 0 );
+
+    // スレ立てからの経過時間であぼーん
+    m_abone_hour_thread = cf.get_option( "abonehourthread", 0 );
+
+    // ローカルプロキシ
+    m_mode_local_proxy = cf.get_option( "mode_local_proxy", 0 );
+    m_local_proxy = cf.get_option( "local_proxy", "" );
+    m_local_proxy_port = cf.get_option( "local_proxy_port", 8080 );
+ 
+    m_mode_local_proxy_w = cf.get_option( "mode_local_proxy_w", 0 );
+    m_local_proxy_w = cf.get_option( "local_proxy_w", "" );
+    m_local_proxy_port_w = cf.get_option( "local_proxy_port_w", 8080 );
+
+    // 書き込み時のデフォルトの名前とメアド
+    m_write_name = cf.get_option( "write_name", "" );
+    m_write_mail = cf.get_option( "write_mail", "" );
+
+    // samba24
+    m_samba_sec = cf.get_option( "samba_sec", 0 );
+
 #ifdef _DEBUG
     std::cout << "modified = " << date_modified() << std::endl;
 #endif
@@ -1058,18 +1437,47 @@ void BoardBase::save_jdboard_info()
 #endif
 
     // あぼーん情報
-    std::string str_abone = MISC::listtostr( m_list_abone_thread );
-    std::string str_abone_word = MISC::listtostr( m_list_abone_word_thread );
-    std::string str_abone_regex = MISC::listtostr( m_list_abone_regex_thread );
+    std::string str_abone_id = MISC::listtostr( m_list_abone_id );
+    std::string str_abone_name = MISC::listtostr( m_list_abone_name );
+    std::string str_abone_word = MISC::listtostr( m_list_abone_word );
+    std::string str_abone_regex = MISC::listtostr( m_list_abone_regex );
+
+    // スレあぼーん情報
+    std::string str_abone_thread = MISC::listtostr( m_list_abone_thread );
+    std::string str_abone_word_thread = MISC::listtostr( m_list_abone_word_thread );
+    std::string str_abone_regex_thread = MISC::listtostr( m_list_abone_regex_thread );
     
     std::ostringstream sstr;
     sstr << "modified = " << date_modified() << std::endl
+         << "modified_localrule = " << m_modified_localrule << std::endl
+         << "modified_setting = " << m_modified_setting << std::endl
          << "view_sort_column = " << m_view_sort_column << std::endl
-         << "view_sort_ascend = " << m_view_sort_ascend << std::endl
+         << "view_sort_mode = " << m_view_sort_mode << std::endl
+         << "view_sort_pre_column = " << m_view_sort_pre_column << std::endl
+         << "view_sort_pre_mode = " << m_view_sort_pre_mode << std::endl
          << "check_noname = " << m_check_noname << std::endl
-         << "abonethread = " << str_abone << std::endl
-         << "abonewordthread = " << str_abone_word << std::endl
-         << "aboneregexthread = " << str_abone_regex << std::endl
+
+    // IDは再起動ごとにリセット
+//         << "aboneid = " << str_abone_id << std::endl
+         << "abonename = " << str_abone_name << std::endl
+         << "aboneword = " << str_abone_word << std::endl
+         << "aboneregex = " << str_abone_regex << std::endl
+
+         << "abonethread = " << str_abone_thread << std::endl
+         << "abonewordthread = " << str_abone_word_thread << std::endl
+         << "aboneregexthread = " << str_abone_regex_thread << std::endl
+         << "abonenumberthread = " << m_abone_number_thread << std::endl
+         << "abonehourthread = " << m_abone_hour_thread << std::endl
+         << "mode_local_proxy = " << m_mode_local_proxy << std::endl
+
+         << "local_proxy = " << m_local_proxy << std::endl
+         << "local_proxy_port = " << m_local_proxy_port << std::endl
+         << "mode_local_proxy_w = " << m_mode_local_proxy_w << std::endl
+         << "local_proxy_w = " << m_local_proxy_w << std::endl
+         << "local_proxy_port_w = " << m_local_proxy_port_w << std::endl
+         << "write_name = " << m_write_name << std::endl
+         << "write_mail = " << m_write_mail << std::endl
+         << "samba_sec = " << m_samba_sec << std::endl
     ;
 
     CACHE::save_rawdata( path_info, sstr.str() );
@@ -1117,7 +1525,7 @@ void BoardBase::save_summary()
     sstr_out << ")";
 
 #ifdef _DEBUG
-    std::cout << sstr_out.str() << std::endl;
+//    std::cout << sstr_out.str() << std::endl;
 #endif
 
     if( count ) CACHE::save_rawdata( path_summary, sstr_out.str() );
@@ -1145,7 +1553,7 @@ void BoardBase::save_board_info()
     std::string logo = "nil";
 
     // board.info 読み込み
-    if( CACHE::is_file_exists( path_info ) == CACHE::EXIST_FILE ){
+    if( CACHE::file_exists( path_info ) == CACHE::EXIST_FILE ){
 
         std::string str_info;
         CACHE::load_rawdata( path_info, str_info );
