@@ -1,4 +1,4 @@
-// ライセンス: 最新のGPL
+// ライセンス: GPL2
 //
 // 板情報クラスのベース
 //
@@ -19,6 +19,14 @@ namespace JDLIB
 
 namespace DBTREE
 {
+    // ローカルプロキシ設定
+    enum
+    {
+        PROXY_GLOBAL,  // 全体設定使用
+        PROXY_DISABLE, // 全体設定無効
+        PROXY_LOCAL    // ローカル設定使用
+    };
+
     class Root;
     class ArticleBase;
 
@@ -35,9 +43,20 @@ namespace DBTREE
         // 一度でも m_list_subject が作られた(=subject.txtを開いた)らtrue
         bool m_list_subject_created;
 
+        // ローカルルールのmodified 時刻
+        std::string m_modified_localrule;
+
+        // setting.txtの modified 時刻
+        std::string m_modified_setting;
+
+        // subjectダウンロード後にローカルルールとsetting.txtをロードする
+        bool m_load_rule_setting;
+
         // ビュワーでソートをする列番号、ソード順
         int m_view_sort_column;
-        bool m_view_sort_ascend;
+        int m_view_sort_mode;
+        int m_view_sort_pre_column;
+        int m_view_sort_pre_mode;
 
         // 名無し書き込み不可
         bool m_check_noname;
@@ -72,10 +91,37 @@ namespace DBTREE
         std::string m_charset;
         std::string m_name; // 板名
 
-        // あぼーん情報
+        // ローカルあぼーん情報(板内の全レス対象)
+        std::list< std::string > m_list_abone_id; // あぼーんするID
+        std::list< std::string > m_list_abone_name; // あぼーんする名前
+        std::list< std::string > m_list_abone_word; // あぼーんする文字列
+        std::list< std::string > m_list_abone_regex; // あぼーんする正規表現
+
+        // ローカルスレあぼーん情報
         std::list< std::string > m_list_abone_thread; // あぼーんするスレのタイトル
         std::list< std::string > m_list_abone_word_thread; // あぼーんする文字列
         std::list< std::string > m_list_abone_regex_thread; // あぼーんする正規表現
+        int m_abone_number_thread; // レスの数
+        int m_abone_hour_thread; // スレ立てからの経過時間
+
+        // ローカルプロキシ設定
+        int m_mode_local_proxy;
+        std::string m_local_proxy;
+        int m_local_proxy_port;
+
+        int m_mode_local_proxy_w;
+        std::string m_local_proxy_w;
+        int m_local_proxy_port_w;
+
+        // 書き込み時のデフォルトの名前とメアド
+        std::string m_write_name;      
+        std::string m_write_mail;
+
+        // 最終書き込み時間
+        struct timeval m_write_time;   
+
+        // samba(秒)
+        time_t m_samba_sec;
 
         char* m_rawdata;
         int m_lng_rawdata;
@@ -83,6 +129,12 @@ namespace DBTREE
         // 情報ファイルを読みこんだらtrueにして2度読みしないようにする
         bool m_read_info;
 
+        // キャッシュにあるこの板に属するスレをデータベースに登録したか
+        bool m_append_articles;
+
+        // 移転を調査するために url_boardbase を読んでいる
+        bool m_read_url_boardbase;
+
         // クッキー, 書き込み時に必要
         std::list< std::string > m_list_cookies_for_write;
 
@@ -115,7 +167,7 @@ namespace DBTREE
         void set_charset( const std::string& str ){ m_charset = str; }
 
         // articleがスレあぼーんされているか
-        const bool get_abone_thread( ArticleBase* article );
+        const bool is_abone_thread( ArticleBase* article );
 
       public:
 
@@ -126,11 +178,24 @@ namespace DBTREE
         // boardviewに表示するスレッドのリストを取得
         std::list< ArticleBase* >& get_list_subject(){ return m_list_subject; }
 
+        // ローカルルールの modified 時刻
+        const std::string& get_modified_localrule() const { return m_modified_localrule; }
+        void set_modified_localrule( const std::string& modified ){ m_modified_localrule = modified; }
+
+        // setting.txtの modified 時刻
+        const std::string& get_modified_setting() const { return m_modified_setting; }
+        void set_modified_setting( const std::string& modified ){ m_modified_setting = modified; }
+
         // boardviewでソートする列番号とソート順
         const int get_view_sort_column() const { return m_view_sort_column; }
-        void set_view_sort_column( int column );
-        const bool get_view_sort_ascend() const { return m_view_sort_ascend; }
-        void set_view_sort_ascend( bool ascend );
+        void set_view_sort_column( int column ){ m_view_sort_column = column; }
+        const int get_view_sort_mode() const { return m_view_sort_mode; }
+        void set_view_sort_mode( int mode ){ m_view_sort_mode = mode; }
+
+        const int get_view_sort_pre_column() const { return m_view_sort_pre_column; }
+        void set_view_sort_pre_column( int column ) { m_view_sort_pre_column = column; }
+        const int get_view_sort_pre_mode() const { return m_view_sort_pre_mode; }
+        void set_view_sort_pre_mode( int mode ){ m_view_sort_pre_mode = mode; }
 
         // 名無し書き込み不可
         const bool get_check_noname() const { return m_check_noname; }
@@ -157,6 +222,9 @@ namespace DBTREE
         virtual const std::string get_proxy_host_w();
         virtual const int get_proxy_port_w();
 
+        // ローカルルール
+        virtual const std::string localrule();
+
         // SETTING.TXT
         virtual const std::string settingtxt();
 
@@ -255,16 +323,63 @@ namespace DBTREE
         // 配下の全articlebaseクラスのあぼーん状態の更新
         void update_abone_all_article();
 
+        // あぼーん情報
+        std::list< std::string > get_abone_list_id(){ return m_list_abone_id; }
+        std::list< std::string > get_abone_list_name(){ return m_list_abone_name; }
+        std::list< std::string > get_abone_list_word(){ return m_list_abone_word; }
+        std::list< std::string > get_abone_list_regex(){ return m_list_abone_regex; }
+
+        // あぼーん状態のリセット(情報セットと状態更新を同時におこなう)
+        void reset_abone( std::list< std::string >& ids, std::list< std::string >& names, std::list< std::string >& words, std::list< std::string >& regexs );
+
+        // あぼ〜ん状態更新(reset_abone()と違って各項目ごと個別におこなう)
+        void add_abone_id( const std::string& id );
+        void add_abone_name( const std::string& name );
+        void add_abone_word( const std::string& word );
+
         // スレあぼーん情報
         std::list< std::string > get_abone_list_thread(){ return m_list_abone_thread; }
         std::list< std::string > get_abone_list_word_thread(){ return m_list_abone_word_thread; }
         std::list< std::string > get_abone_list_regex_thread(){ return m_list_abone_regex_thread; }
+        const int get_abone_number_thread(){ return m_abone_number_thread; }
+        const int get_abone_hour_thread(){ return m_abone_hour_thread; }
 
         // スレあぼーん状態の更新
         void update_abone_thread();
 
         // スレあぼーん状態のリセット(情報セットと状態更新を同時におこなう)
-        void reset_abone_thread( std::list< std::string >& threads, std::list< std::string >& words, std::list< std::string >& regexs );
+        void reset_abone_thread( std::list< std::string >& threads, std::list< std::string >& words, std::list< std::string >& regexs,
+                                 const int number, const int hour );
+
+        // ローカルプロキシ設定
+        const int get_mode_local_proxy() const { return m_mode_local_proxy; }
+        const std::string& get_local_proxy() const { return m_local_proxy; }
+        const int get_local_proxy_port() const { return m_local_proxy_port; }
+        void set_mode_local_proxy( int mode ){ m_mode_local_proxy = mode; }
+        void set_local_proxy( const std::string& proxy ){ m_local_proxy = proxy; }
+        void set_local_proxy_port( int port ){ m_local_proxy_port = port; }
+
+        const int get_mode_local_proxy_w() const { return m_mode_local_proxy_w; }
+        const std::string& get_local_proxy_w() const { return m_local_proxy_w; }
+        const int get_local_proxy_port_w() const { return m_local_proxy_port_w; }
+        void set_mode_local_proxy_w( int mode ){ m_mode_local_proxy_w = mode; }
+        void set_local_proxy_w( const std::string& proxy ){ m_local_proxy_w = proxy; }
+        void set_local_proxy_port_w( int port ){ m_local_proxy_port_w = port; }
+
+        // 書き込み時のデフォルトの名前とメアド
+        const std::string& get_write_name() const { return  m_write_name; }
+        const std::string& get_write_mail() const { return m_write_mail; }
+
+        void set_write_name( const std::string& name ){ m_write_name = name; }
+        void set_write_mail( const std::string& mail ){ m_write_mail = mail; }
+
+        // 最終書き込み時間
+        void update_writetime();
+        const time_t& get_write_time() const { return m_write_time.tv_sec; } // 秒
+        const time_t get_write_pass(); // 経過時間(秒)
+        const time_t get_samba_sec() const { return m_samba_sec; } // samba(秒)
+        void set_samba_sec( time_t sec ){ m_samba_sec = sec; }
+        time_t get_write_leftsec(); // 書き込み可能までの残り秒
 
         // 板情報の取得
         void read_info();
@@ -272,6 +387,9 @@ namespace DBTREE
         // 情報保存
         void save_info();
         
+        // キャッシュ内のログ検索
+        std::list< std::string > search_cache( const std::string& query, bool mode_or, bool& stop );
+
       private:
 
         void clear();
@@ -286,6 +404,8 @@ namespace DBTREE
         virtual ArticleBase* append_article( const std::string& id, bool cached );
         virtual void parse_subject( const char* str_subject_txt ){}
 
+        std::list< std::string > get_filelist_in_cache();
+
         void read_board_info();
         void append_all_article_in_cache();
 
@@ -293,9 +413,13 @@ namespace DBTREE
         void save_board_info();
         void save_jdboard_info();
 
-        // setting.txtの読み込み及びダウンロード
-        virtual void load_setting(){}
-        virtual void download_setting(){}
+        // ローカルルールとsetting.txtの読み込み及びダウンロード
+        virtual void load_rule_setting(){}
+        virtual void download_rule_setting(){}
+
+        // レス数であぼーん(グローバル)
+        // 2ch以外の板ではキャンセルする
+        virtual const int get_abone_number_global(){ return 0; }
     };
 }
 
