@@ -4,16 +4,20 @@
 #include "jddebug.h"
 
 #include "imageadmin.h"
+#include "imagewin.h"
 
 #include "dbimg/imginterface.h"
 
 #include "skeleton/view.h"
+#include "skeleton/msgdiag.h"
+#include "skeleton/filediag.h"
 
 #include "command.h"
 #include "cache.h"
 #include "viewfactory.h"
 #include "global.h"
 #include "session.h"
+#include "httpcode.h"
 
 #include "jdlib/miscutil.h"
 #include "jdlib/miscmsg.h"
@@ -71,25 +75,41 @@ ImageAdmin::~ImageAdmin()
 
     // 開いているURLを保存
     SESSION::set_image_URLs( get_URLs() );
+    SESSION::set_image_locked( get_locked() );
     SESSION::set_image_page( get_current_page() );
-}
 
+    close_window();
+}
 
 
 // 前回開いていたURLを復元
 void ImageAdmin::restore()
 {
-    std::list< std::string > list_tmp;
-    std::list< std::string >::iterator it_tmp;
+#ifdef _DEBUG
+    std::cout << "ImageAdmin::restore\n";
+#endif
 
-    list_tmp = SESSION::image_URLs();
-    it_tmp = list_tmp.begin();
-    for( ; it_tmp != list_tmp.end(); ++it_tmp ){
+    std::list< std::string > list_url = SESSION::image_URLs();
+    std::list< std::string >::iterator it_url= list_url.begin();
 
-        if( !(*it_tmp).empty() ){
-            COMMAND_ARGS command_arg;
-            command_arg.command = "open_view";
-            command_arg.url = (*it_tmp);
+    std::list< bool > list_locked = SESSION::get_image_locked();
+    std::list< bool >::iterator it_locked = list_locked.begin();
+
+    for( ; it_url != list_url.end(); ++it_url ){
+
+        COMMAND_ARGS command_arg;
+        command_arg.command = "open_view";
+
+        // タブのロック状態
+        std::string lock;
+        if( it_locked != list_locked.end() ){
+            if( (*it_locked ) ) lock = "lock";
+            ++it_locked;
+        }
+
+        if( !(*it_url).empty() ){
+            command_arg.url = (*it_url);
+            command_arg.arg3 = lock;
 
             open_view( command_arg );
         }
@@ -105,7 +125,7 @@ void ImageAdmin::restore()
 
 void ImageAdmin::switch_admin()
 {
-    CORE::core_set_command( "switch_image" );
+    if( ! has_focus() ) CORE::core_set_command( "switch_image" );
 }
 
 
@@ -160,9 +180,10 @@ void ImageAdmin::clock_in()
         if( view ) view->clock_in();
     }
 
-    // アクティブなviewにだけクロックを送る
-    // admin が画面に表示されていないなら何もしない
-    if( SESSION::is_img_shown() ){
+    // 画像が表示されている場合viewにクロックを回す
+    if( SESSION::is_shown_win_img() ){
+
+        // アクティブなviewにだけクロックを送る
         SKELETON::View* view = get_current_view();
         if( view ) view->clock_in();
     }
@@ -178,6 +199,8 @@ void ImageAdmin::clock_in()
             m_counter_scroll = 0;
         }
     }
+
+    if( get_jdwin() ) get_jdwin()->clock_in();
 }
 
 
@@ -226,6 +249,9 @@ void ImageAdmin::command_local( const COMMAND_ARGS& command )
 
     else if( command.command  == "close_all_views" ) close_other_views( std::string() );
 
+    // キャッシュに無いviewを削除
+    else if( command.command  == "close_nocached_views" ) close_nocached_views();
+
     // 画面のスクロール
     else if( command.command == "scroll_up" ){
         SKELETON::View* view = get_current_view();
@@ -256,28 +282,28 @@ void ImageAdmin::open_view( const COMMAND_ARGS& command )
     std::cout << "ImageAdmin::open_view url = " << command.url << std::endl;
 #endif
 
-    // 既に表示されているなら表示
-    if( get_view( command.url ) ){
-        switch_img( command.url );
-        return;
-    }
+    // まだ表示されていない
+    if( ! get_view( command.url ) ){
 
-    // アイコン作成 & 表示
-    SKELETON::View* icon = Gtk::manage( CORE::ViewFactory( CORE::VIEW_IMAGEICON, command.url ) );
-    if( icon ){
-        icon->set_size_request( ICON_SIZE ,  ICON_SIZE );
-        icon->show_view();
-        m_iconbox.pack_start( *icon, Gtk::PACK_SHRINK );
-        m_iconbox.show_all_children();
-    }
+        // アイコン作成 & 表示
+        SKELETON::View* icon = Gtk::manage( CORE::ViewFactory( CORE::VIEW_IMAGEICON, command.url ) );
+        if( icon ){
+            if( command.arg3 == "lock" ) icon->lock();
+            icon->set_size_request( ICON_SIZE ,  ICON_SIZE );
+            icon->show_view();
+            m_iconbox.pack_start( *icon, Gtk::PACK_SHRINK );
+            m_iconbox.show_all_children();
+        }
 
-    // view作成
-    SKELETON::View* view = Gtk::manage( CORE::ViewFactory( CORE::VIEW_IMAGEVIEW, command.url ) );
-    if( view ){
-        view->show_view();
-        m_list_view.push_back( view );
+        // view作成
+        SKELETON::View* view = Gtk::manage( CORE::ViewFactory( CORE::VIEW_IMAGEVIEW, command.url ) );
+        if( view ){
+            view->show_view();
+            m_list_view.push_back( view );
+        }
     }
 
+    open_window();
     switch_img( command.url );
 }
 
@@ -459,6 +485,7 @@ void ImageAdmin::close_view( const std::string& url )
     SKELETON::View* view = get_view( url );
 
     if( ! icon && ! view ) return;
+    if( DBIMG::is_cached( url ) && icon->is_locked() ) return;
 
     // 現在表示中のviewを閉じた場合は次か前の画像に切り替える
     if( view && view == get_current_view() ){
@@ -491,11 +518,51 @@ void ImageAdmin::close_view( const std::string& url )
         delete view;
     }
 
-    if( m_iconbox.children().size() == 0 ) CORE::core_set_command( "empty_page", get_url() );
+    if( empty() ){
+
+        close_window();
+        CORE::core_set_command( "empty_page", get_url() );
+    }
     else if( ! url_next.empty() ) switch_img( url_next );
 }
 
 
+//
+// ウィンドウ開く
+//
+void ImageAdmin::open_window()
+{
+    ImageWin* win = dynamic_cast< ImageWin* >( get_jdwin() );
+
+    if( ! SESSION::get_embedded_img() && ! win && ! empty() ){
+        win = new IMAGE::ImageWin();
+        set_jdwin( win );
+        win->pack_remove_tab( false, m_tab );
+        win->pack_remove_end( false, m_view );
+        win->show_all();
+    }
+    else if( win && win->is_hide() ){
+        win->show();
+        win->focus_in();
+    }
+}
+
+
+//
+// ウィンドウ閉じる
+//
+void ImageAdmin::close_window()
+{
+    ImageWin* win = dynamic_cast< ImageWin* >( get_jdwin() );
+
+    if( win ){
+        win->pack_remove_tab( true, m_tab );
+        win->pack_remove_end( true, m_view );
+        delete_jdwin();
+    }
+}
+
+
 //
 // url 以外の画像を閉じる
 //
@@ -541,32 +608,51 @@ void ImageAdmin::close_right_views( const std::string& url )
 }
 
 
+//
+// キャッシュに無い画像を閉じる
+//
+void ImageAdmin::close_nocached_views()
+{
+    Gtk::Box_Helpers::BoxList::iterator it = m_iconbox.children().begin();
+    for(; it !=  m_iconbox.children().end(); ++it ){
+        SKELETON::View* view = dynamic_cast< SKELETON::View* >( it->get_widget() );
+        if( view ){
+            std::string url = view->get_url();
+            if( ! DBIMG::is_cached( url ) && DBIMG::get_code( url ) == HTTP_INIT ) set_command( "close_view", url );
+        }
+    }
+}
+
 
 //
 // 現在のviewをフォーカスする
 //
 // 他のクラスからは直接呼ばないで、set_command()経由で呼ぶこと
 //
-void ImageAdmin::focus_current_view()
+void ImageAdmin::focus_view( int)
 {
 #ifdef _DEBUG
-    std::cout << "ImageAdmin::focus_current_view\n";
+    std::cout << "ImageAdmin::focus_view\n";
 #endif
 
     SKELETON::View* view_icon = get_current_icon();
     if( view_icon ) {
 
+        if( get_jdwin() ) get_jdwin()->focus_in();
+
         focus_out_all();
 
         view_icon->focus_view();
-        CORE::core_set_command( "set_url", view_icon->get_url() );
 
         SKELETON::View* view = get_current_view();
-        if( view ) CORE::core_set_command( "set_status", "", view->get_status() );
+        if( view ) update_status( view, false );
     }
 }
 
-
+void ImageAdmin::focus_current_view()
+{
+    focus_view( 0 );
+}
 
 
 //
@@ -675,7 +761,7 @@ SKELETON::View* ImageAdmin::get_icon( const std::string& url)
 //
 // アイコン取得(番号で)
 //
-SKELETON::View* ImageAdmin::get_nth_icon( unsigned int n )
+SKELETON::View* ImageAdmin::get_nth_icon( const unsigned int n )
 {
     if( n >= m_iconbox.children().size() ) return NULL;
 
@@ -794,6 +880,36 @@ void ImageAdmin::slot_release_right()
     m_scroll = SCROLL_NO;
 }
 
+
+
+//
+// 画像ファイルのコピー
+//
+bool ImageAdmin::copy_file( const std::string& url, const std::string& path_from, const std::string& path_to )
+{
+#ifdef _DEBUG
+    std::cout << "ImageAdmin::copy_file url = " << url << std::endl
+              << "from = " << path_from << std::endl
+              << "to = " << path_to << std::endl;
+#endif
+
+    if( ! CACHE::jdcopy( path_from, path_to ) ){
+
+        // ビューを切り替えてURLやステータス更新
+        switch_img( url );
+        SKELETON::View* view = get_current_view();
+        if( view ) update_status( view, true );
+
+        SKELETON::MsgDiag mdiag( get_win(), path_to + "\n\nの保存に失敗しました。\nハードディスクの容量やパーミッションなどを確認してください。\n\n画像保存をキャンセルしました。原因を解決してからもう一度保存を行ってください。" );
+        mdiag.run();
+
+        return false;
+    }
+
+    return true;
+}
+
+
 //
 // すべて保存
 //
@@ -808,14 +924,9 @@ void ImageAdmin::save_all()
     std::list< std::string > list_urls = get_URLs();
 
     // ディレクトリ選択
-    Gtk::FileChooserDialog diag( "save", Gtk::FILE_CHOOSER_ACTION_SELECT_FOLDER );
+    SKELETON::FileDiag diag( get_win(), "保存先選択", Gtk::FILE_CHOOSER_ACTION_SELECT_FOLDER );
 
     diag.set_current_folder( SESSION::dir_img_save() );
-
-    // ボタン追加 + saveボタンをデフォルトボタンにセット
-    diag.add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
-    diag.add_button( Gtk::Stock::SAVE, Gtk::RESPONSE_ACCEPT );
-    diag.set_default_response( Gtk::RESPONSE_ACCEPT );
     
     if( diag.run() == Gtk::RESPONSE_ACCEPT ){
 
@@ -839,7 +950,7 @@ void ImageAdmin::save_all()
                 std::string url = (*it);
                 if( ! DBIMG::is_cached( url ) ) continue;
 
-                std::string path_from = CACHE::path_img( url );
+                std::string path_from = DBIMG::get_cache_path( url );
                 std::string path_to = path_dir + MISC::get_filename( url );
 
 #ifdef _DEBUG
@@ -851,20 +962,26 @@ void ImageAdmin::save_all()
                 if( CACHE::file_exists( path_to ) == CACHE::EXIST_FILE ){
 
                     // すべて上書き
-                    if( overwrite == 1 ) CACHE::jdcopy( path_from, path_to ); 
+                    if( overwrite == 1 ){
+                        if( ! copy_file( url, path_from, path_to ) ) return;
+                    }
                     else if( overwrite != -1 ){
-                    
+
+                        // ビューを切り替えてURLやステータス更新
                         switch_img( url );
+                        SKELETON::View* view = get_current_view();
+                        if( view ) update_status( view, true );
 
                         for(;;){
 
-                            Gtk::MessageDialog mdiag( "ファイルが存在します。ファイル名を変更しますか？", 
-                                                      false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE );
+                            SKELETON::MsgDiag mdiag( get_win(), "ファイルが存在します。ファイル名を変更して保存しますか？", 
+                                                     false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE );
                             mdiag.add_button( Gtk::Stock::NO, Gtk::RESPONSE_NO );
                             mdiag.add_button( Gtk::Stock::YES, Gtk::RESPONSE_YES );
                             mdiag.add_button( "上書き", Gtk::RESPONSE_YES + 100 );
                             mdiag.add_button( "すべていいえ", Gtk::RESPONSE_NO + 200 );
                             mdiag.add_button( "すべて上書き", Gtk::RESPONSE_YES + 200 );
+
                             int ret = mdiag.run();
                             mdiag.hide();
 
@@ -875,12 +992,12 @@ void ImageAdmin::save_all()
                                     overwrite = 1;
                                     // 上書き
                                 case Gtk::RESPONSE_YES + 100:
-                                    CACHE::jdcopy( path_from, path_to );
+                                    if( ! copy_file( url, path_from, path_to ) ) return;
                                     break;
 
                                     // 名前変更
                                 case Gtk::RESPONSE_YES:
-                                    if( ! DBIMG::save( url, path_to ) ) continue;
+                                    if( ! DBIMG::save( url, get_win(), path_to ) ) continue;
                                     break;
 
                                     //  すべていいえ
@@ -898,10 +1015,47 @@ void ImageAdmin::save_all()
                     }
 
                 }
-                else CACHE::jdcopy( path_from, path_to );
+                else if( ! copy_file( url, path_from, path_to ) ) return;
             }
 
         }
         else MISC::ERRMSG( "can't create " + path_dir );
     }
 }
+
+
+// ページがロックされているかリストで取得
+std::list< bool > ImageAdmin::get_locked()
+{
+    std::list< bool > locked;
+
+    Gtk::Box_Helpers::BoxList::iterator it = m_iconbox.children().begin();
+    for(; it !=  m_iconbox.children().end(); ++it ){
+        SKELETON::View* view = dynamic_cast< SKELETON::View* >( it->get_widget() );
+        if( view ) locked.push_back( view->is_locked() );
+    }
+
+    return locked;
+}
+
+
+// タブのロック/アンロック
+const bool ImageAdmin::is_locked( const int page )
+{
+    SKELETON::View* view = get_nth_icon( page );
+    if( view ) return view->is_locked();
+
+    return false;
+}
+
+void ImageAdmin::lock( const int page )
+{
+    SKELETON::View* view = get_nth_icon( page );
+    if( view ) return view->lock();
+}
+
+void ImageAdmin::unlock( const int page )
+{
+    SKELETON::View* view = get_nth_icon( page );
+    if( view ) return view->unlock();
+}
