@@ -32,6 +32,9 @@ ImageViewIcon::ImageViewIcon( const std::string& url )
     std::cout << "ImageViewIcon::ImageViewIcon : " << get_url() << std::endl;
 #endif
 
+    // コントロールモード設定
+    get_control().add_mode( CONTROL::MODE_IMAGEICON );
+
     //枠を描くためにm_eventの外にもう一つEventBoxを作る ( Gtk::HBox は modify_fg() 無効なので )
     m_event_frame = Gtk::manage( new Gtk::EventBox() );
     pack_start( *m_event_frame );
@@ -80,7 +83,6 @@ void ImageViewIcon::clock_in()
 
         // 画像表示
         show_view();
-        get_imagearea()->show_image();
     }
 }
 
@@ -125,6 +127,7 @@ void ImageViewIcon::show_view()
     if( get_imagearea() ) get_imagearea()->show_image();
 
     // 画像貼り付け
+    // ロード中の時はclock_in()経由でもう一度 show_view()が呼び出される
     else{
 
         set_imagearea( Gtk::manage( new ImageAreaIcon( get_url() ) ) );
@@ -180,7 +183,7 @@ bool ImageViewIcon::slot_scroll_event( GdkEventScroll* event )
     if( event->direction == GDK_SCROLL_DOWN ) control = CONTROL::TabRight;
 
     ImageViewBase::operate_view( control );
-    CORE::core_set_command( "switch_image" );
+    IMAGE::get_admin()->set_command( "switch_admin" );
 
     return true;
 }
