@@ -3,8 +3,11 @@
 //#define _DEBUG
 #include "jddebug.h"
 
+#include "messageadmin.h"
 #include "post.h"
 
+#include "skeleton/msgdiag.h"
+
 #include "jdlib/loaderdata.h"
 #include "jdlib/jdiconv.h"
 #include "jdlib/miscmsg.h"
@@ -47,8 +50,10 @@ Post::~Post()
 #endif
 
     clear();
-}
 
+    if( m_writingdiag ) delete m_writingdiag;
+    m_writingdiag = NULL;
+}
 
 
 void Post::clear()
@@ -56,6 +61,16 @@ void Post::clear()
     if( m_rawdata ) free( m_rawdata );
     m_rawdata = NULL;
 
+    if( m_writingdiag ) m_writingdiag->hide();
+}
+
+
+void Post::emit_sigfin()
+{
+    m_sig_fin.emit();
+
+    clear();
+
     if( m_writingdiag ) delete m_writingdiag;
     m_writingdiag = NULL;
 }
@@ -75,7 +90,8 @@ void Post::post_msg()
     // 書き込み中ダイアログ表示
     Gtk::Window* toplevel = dynamic_cast< Gtk::Window* >( m_parent->get_toplevel() );
     if( ! CONFIG::get_hide_writing_dialog() && toplevel ){
-        m_writingdiag = new Gtk::MessageDialog( *toplevel, "書き込み中・・・", false, Gtk::MESSAGE_INFO, Gtk::BUTTONS_NONE, false );
+
+        if( ! m_writingdiag ) m_writingdiag = new SKELETON::MsgDiag( *toplevel, "書き込み中・・・", false, Gtk::MESSAGE_INFO, Gtk::BUTTONS_NONE, false );
         m_writingdiag->show();
 
         // gtkのバージョンによってはラベルが選択状態になっている場合があるので
@@ -167,8 +183,9 @@ void Post::receive_finish()
     if( get_code() != HTTP_OK
         && ! ( get_code() == HTTP_REDIRECT && ! location().empty() ) // リダイレクトは成功(かもしれない)
         ){
+
         m_errmsg = get_str_code();
-        m_sig_fin.emit();
+        emit_sigfin();
         return;
     }
 
@@ -188,25 +205,44 @@ void Post::receive_finish()
     regex.exec( ".*<title>([^<]*)</title>.*", str, 0, true, false );
     title = MISC::remove_space( regex.str( 1 ) );
 
+    // 2chタグ
+    regex.exec( ".*2ch_X:([^\\-]*)\\-\\->.*", str, 0, false, false );
+    tag_2ch = MISC::remove_space( regex.str( 1 ) );
+
     // エラー
     // 一番内側の<b>〜</b>を探す
     m_errmsg = std::string();
     if( regex.exec( "([^>]|[^b]>)*<b>(([^>]|[^b]>)*)</b>.*", str, 0, true, false ) ){
-
         m_errmsg = regex.str( 2 );
+    }
+    else
+        if( tag_2ch.find( "error" ) != std::string::npos ){
+        if( regex.exec( "error +-->(.*)</body>", str, 0, true, false ) ) m_errmsg = regex.str( 1 );
+    }
+
+    if( ! m_errmsg.empty() ){
+
+        m_errmsg = MISC::replace_str( m_errmsg, "\n", "" ); 
 
         // <a 〜を取り除く
         while( regex.exec( "(.*)<a +href *= *\"([^\"]*)\" *>(.*)</a>(.*)", m_errmsg ) ){
             m_errmsg = regex.str( 1 ) + " " + regex.str( 2 ) + " " + regex.str( 3 ) + regex.str( 4 );
         }
 
-        // 改行
+        // 改行その他
         m_errmsg= MISC::replace_str( m_errmsg, "<br>", "\n" );
-    }
+        m_errmsg= MISC::replace_str( m_errmsg, "<hr>", "\n-------------------\n" );
 
-    // 2chタグ
-    regex.exec( ".*2ch_X:([^\\-]*)\\-\\->.*", str, 0, false, false );
-    tag_2ch = MISC::remove_space( regex.str( 1 ) );
+        // samba秒取得
+        if( regex.exec( "ＥＲＲＯＲ +- +593 +([0-9]+) +sec", m_errmsg ) ){
+            time_t sec = atoi( regex.str( 1 ).c_str() );
+#ifdef _DEBUG
+            std::cout << "samba = " << sec << std::endl;
+#endif
+            DBTREE::board_set_samba_sec( m_url, sec );
+            DBTREE::board_update_writetime( m_url );
+        }
+    }
 
     // 書き込み確認
     regex.exec( ".*<font size=\\+1 color=#FF0000>([^<]*)</font>.*", str );
@@ -252,7 +288,7 @@ void Post::receive_finish()
 #endif        
 
         DBTREE::article_update_writetime( m_url );
-        m_sig_fin.emit();
+        emit_sigfin();
         return;
     }
 
@@ -267,28 +303,30 @@ void Post::receive_finish()
         if( ! CONFIG::get_always_write_ok() ){
 
             std::string diagmsg = MISC::replace_str( msg, "<br>", "\n" );
-            Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( diagmsg, false,
-                                                                Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE, false );
+
+            SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(),
+                                     diagmsg, false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE, false );
             Gtk::CheckButton ckbt( "次回から表示しない(_D)", true );
-            mdiag->get_vbox()->pack_start( ckbt, Gtk::PACK_SHRINK );
-            mdiag->add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
+            mdiag.get_vbox()->pack_start( ckbt, Gtk::PACK_SHRINK );
+            mdiag.add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
 
             // OKボタンをデフォルトにする
             Gtk::Button okbt( Gtk::Stock::OK );
-            mdiag->add_action_widget( okbt, Gtk::RESPONSE_OK );
+            mdiag.add_action_widget( okbt, Gtk::RESPONSE_OK );
             okbt.set_flags( Gtk::CAN_DEFAULT );
             okbt.grab_default();
             okbt.grab_focus();
 
-            mdiag->show_all_children();
+            mdiag.show_all_children();
 
-            int ret = mdiag->run();
+            int ret = mdiag.run();
             bool ckbt_active = ckbt.get_active();
-            delete mdiag;
+            mdiag.hide();
 
             if( ret != Gtk::RESPONSE_OK ){
+
                 set_code( HTTP_CANCEL );
-                m_sig_fin.emit();
+                emit_sigfin();
                 return;
             }
             CONFIG::set_always_write_ok( ckbt_active );
@@ -326,7 +364,7 @@ void Post::receive_finish()
         MISC::ERRMSG( str );
 
         set_code( HTTP_ERR );
-        m_sig_fin.emit();
+        emit_sigfin();
         return;
     }
 }
