@@ -4,6 +4,7 @@
 #include "jddebug.h"
 
 #include "admin.h"
+#include "window.h"
 #include "view.h"
 #include "dragnote.h"
 
@@ -16,6 +17,7 @@
 #include "global.h"
 #include "controlutil.h"
 #include "controlid.h"
+#include "updatemanager.h"
 
 
 #define MOVETAB_MENU { 5, 10, 15, 20, 25, 30 }
@@ -26,17 +28,17 @@ using namespace SKELETON;
 
 
 Admin::Admin( const std::string& url )
-    : m_url( url )
-    , m_notebook( 0 )
-    , m_focus( false )
+    : m_url( url ),
+      m_win( NULL ),
+      m_notebook( NULL ),
+      m_focus( false )
 {
-    m_disp.connect( sigc::mem_fun( *this, &Admin::exec_command ) );
-
     m_notebook = new DragableNoteBook();
 
     m_notebook->signal_switch_page().connect( sigc::mem_fun( *this, &Admin::slot_switch_page ) );
     m_notebook->set_scrollable( true );
 
+    m_notebook->sig_tab_click().connect( sigc::mem_fun( *this, &Admin::slot_tab_click ) );
     m_notebook->sig_tab_close().connect( sigc::mem_fun( *this, &Admin::slot_tab_close ) );
     m_notebook->sig_tab_reload().connect( sigc::mem_fun( *this, &Admin::slot_tab_reload ) );
     m_notebook->sig_tab_menu().connect( sigc::mem_fun( *this, &Admin::slot_tab_menu ) );
@@ -46,30 +48,74 @@ Admin::Admin( const std::string& url )
     m_notebook->sig_drag_end().connect( sigc::mem_fun(*this, &Admin::slot_drag_end ) );
 
     m_list_command.clear();
+}
 
+
+Admin::~Admin()
+{
+#ifdef _DEBUG
+    std::cout << "Admin::~Admin " << m_url << std::endl;
+#endif
+
+    // デストラクタの中からdispatchを呼ぶと落ちるので dispatch不可にする
+    set_dispatchable( false );
+
+    int pages = m_notebook->get_n_pages();
+
+#ifdef _DEBUG
+    std::cout << "pages = " << pages << std::endl;
+#endif
+    if( pages ){
+
+        for( int i = 0; i < pages; ++i ){
+
+            SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( 0 ) );
+
+            m_notebook->remove_page( 0 );
+
+            if( view ) delete view;
+        }
+    }
+    m_list_command.clear();
+
+    close_window();
+    delete_jdwin();
+
+    if( m_notebook ) delete m_notebook;
+}
+
+
+//
+// メニューのセットアップ
+//
+void Admin::setup_menu( const bool enable_checkupdate )
+{
     // 右クリックメニュー
     m_action_group = Gtk::ActionGroup::create();
     m_action_group->add( Gtk::Action::create( "Quit", "Quit" ), sigc::mem_fun( *this, &Admin::slot_close_tab ) );
 
-    m_action_group->add( Gtk::Action::create( "CloseOther_Menu", "他のタブを閉じる" ) );
-    m_action_group->add( Gtk::Action::create( "CloseOther", "閉じる" ), sigc::mem_fun( *this, &Admin::slot_close_other_tabs ) );
-    m_action_group->add( Gtk::Action::create( "CloseLeft_Menu", "左のタブを閉じる" ) );
-    m_action_group->add( Gtk::Action::create( "CloseLeft", "閉じる" ), sigc::mem_fun( *this, &Admin::slot_close_left_tabs ) );
-    m_action_group->add( Gtk::Action::create( "CloseRight_Menu", "右のタブを閉じる" ) );
-    m_action_group->add( Gtk::Action::create( "CloseRight", "閉じる" ), sigc::mem_fun( *this, &Admin::slot_close_right_tabs ) );
-    m_action_group->add( Gtk::Action::create( "CloseAll_Menu", "全てのタブを閉じる" ) );
-    m_action_group->add( Gtk::Action::create( "CloseAll", "閉じる" ), sigc::mem_fun( *this, &Admin::slot_close_all_tabs ) );
+    m_action_group->add( Gtk::ToggleAction::create( "LockTab", "タブをロックする", std::string(), false ),
+                         sigc::mem_fun( *this, &Admin::slot_lock ) );
 
-    m_action_group->add( Gtk::Action::create( "ReloadAll_Menu", "全てのタブを更新" ) );
-    m_action_group->add( Gtk::Action::create( "ReloadAll", "更新する" ), sigc::mem_fun( *this, &Admin::slot_reload_all_tabs ) );
-    m_action_group->add( Gtk::Action::create( "CancelReloadAll", "更新キャンセル" ),
-                         sigc::mem_fun( *this, &Admin::slot_cancel_reload_all_tabs ) );
+    m_action_group->add( Gtk::Action::create( "Close_Tab_Menu", "複数のタブを閉じる" ) );
+    m_action_group->add( Gtk::Action::create( "CloseOther", "他のタブ" ), sigc::mem_fun( *this, &Admin::slot_close_other_tabs ) );
+    m_action_group->add( Gtk::Action::create( "CloseLeft", "左←のタブ" ), sigc::mem_fun( *this, &Admin::slot_close_left_tabs ) );
+    m_action_group->add( Gtk::Action::create( "CloseRight", "右→のタブ" ), sigc::mem_fun( *this, &Admin::slot_close_right_tabs ) );
+    m_action_group->add( Gtk::Action::create( "CloseAll", "全てのタブ" ), sigc::mem_fun( *this, &Admin::slot_close_all_tabs ) );
 
+    m_action_group->add( Gtk::Action::create( "Reload_Tab_Menu", "全てのタブの再読み込み" ) );
+    m_action_group->add( Gtk::Action::create( "CheckUpdateAll", "更新チェックのみ" ), sigc::mem_fun( *this, &Admin::slot_check_update_all_tabs ) );
+    m_action_group->add( Gtk::Action::create( "CheckUpdateReloadAll", "更新されたタブを再読み込み" ),
+                         sigc::mem_fun( *this, &Admin::slot_check_update_reload_all_tabs ) );
+    m_action_group->add( Gtk::Action::create( "ReloadAll", "再読み込み" ), sigc::mem_fun( *this, &Admin::slot_reload_all_tabs ) );
+    m_action_group->add( Gtk::Action::create( "CancelReloadAll", "キャンセル" ), sigc::mem_fun( *this, &Admin::slot_cancel_reload_all_tabs ) );
 
     m_action_group->add( Gtk::Action::create( "OpenBrowser", "ブラウザで開く" ), sigc::mem_fun( *this, &Admin::slot_open_by_browser ) );
     m_action_group->add( Gtk::Action::create( "CopyURL", "URLをコピー" ), sigc::mem_fun( *this, &Admin::slot_copy_url ) );
     m_action_group->add( Gtk::Action::create( "CopyTitle", "タイトルとURLをコピー" ), sigc::mem_fun( *this, &Admin::slot_copy_title_url ) );
 
+    m_action_group->add( Gtk::Action::create( "Preference", "プロパティ..."), sigc::mem_fun( *this, &Admin::show_preference ) );
+
     m_ui_manager = Gtk::UIManager::create();    
     m_ui_manager->insert_action_group( m_action_group );
 
@@ -80,27 +126,36 @@ Admin::Admin( const std::string& url )
 
     // 通常
     "<popup name='popup_menu'>"
+
+    "<menuitem action='LockTab'/>"
+    "<separator/>"
+
     "<menuitem action='Quit'/>"
     "<separator/>"
 
-    "<menu action='CloseAll_Menu'>"
+    "<menu action='Close_Tab_Menu'>"
     "<menuitem action='CloseAll'/>"
-    "</menu>"
-    "<menu action='CloseOther_Menu'>"
     "<menuitem action='CloseOther'/>"
-    "</menu>"
-    "<menu action='CloseLeft_Menu'>"
     "<menuitem action='CloseLeft'/>"
-    "</menu>"
-    "<menu action='CloseRight_Menu'>"
     "<menuitem action='CloseRight'/>"
     "</menu>"
     "<separator/>"
 
-    "<menu action='ReloadAll_Menu'>"
-    "<menuitem action='ReloadAll'/>"
-    "</menu>"
+    "<menu action='Reload_Tab_Menu'>"
+    "<menuitem action='ReloadAll'/>";
+
+    if( enable_checkupdate ){
+
+        str_ui += 
+        "<menuitem action='CheckUpdateAll'/>"
+        "<menuitem action='CheckUpdateReloadAll'/>";
+    }
+
+    str_ui +=
+
+    "<separator/>"
     "<menuitem action='CancelReloadAll'/>"
+    "</menu>"
     "<separator/>"
 
     "<menuitem action='OpenBrowser'/>"
@@ -109,6 +164,9 @@ Admin::Admin( const std::string& url )
     "<menuitem action='CopyURL'/>"
     "<menuitem action='CopyTitle'/>"
 
+    "<separator/>"
+    "<menuitem action='Preference'/>"
+
     "</popup>"
 
 
@@ -156,40 +214,35 @@ Admin::Admin( const std::string& url )
 }
 
 
-Admin::~Admin()
-{
-#ifdef _DEBUG
-    std::cout << "Admin::~Admin " << m_url << std::endl;
-#endif
-    int pages = m_notebook->get_n_pages();
-
-#ifdef _DEBUG
-    std::cout << "pages = " << pages << std::endl;
-#endif
-    if( pages ){
-
-        for( int i = 0; i < pages; ++i ){
-
-            SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( 0 ) );
-
-            m_notebook->remove_page( 0 );
-
-            if( view ) delete view;
-        }
-    }
-    m_list_command.clear();
-
-    if( m_notebook ) delete m_notebook;
-}
-
-
-
 Gtk::Widget* Admin::get_widget()
 {
     return dynamic_cast< Gtk::Widget*>( m_notebook );
 }
 
 
+Gtk::Window* Admin::get_win()
+{
+    return dynamic_cast< Gtk::Window*>( m_win );
+}
+
+
+void Admin::delete_jdwin()
+{
+    if( m_win ){
+        delete m_win;
+        m_win = NULL;
+    }
+}
+
+
+const bool Admin::is_booting()
+{
+    if( get_jdwin() && get_jdwin()->is_booting() ) return true;
+
+    return ( has_commands() );
+}
+
+
 // SIGHUPを受け取った
 void Admin::shutdown()
 {
@@ -247,7 +300,6 @@ std::list<std::string> Admin::get_URLs()
 }
 
 
-
 //
 // クロック入力
 //
@@ -268,6 +320,33 @@ void Admin::clock_in()
     }
 
     m_notebook->clock_in();
+
+    if( m_win ) m_win->clock_in();
+}
+
+
+
+//
+// コマンド受付(通常)
+//
+void Admin::set_command( const std::string& command, const std::string& url,
+                         const std::string& arg1, const std::string& arg2,
+                         const std::string& arg3, const std::string& arg4,
+                         const std::string& arg5, const std::string& arg6 )
+{
+    set_command_impl( false, command, url, arg1, arg2, arg3, arg4, arg5, arg6 );
+}
+
+
+//
+// コマンド受付(即実行)
+//
+void Admin::set_command_immediately( const std::string& command, const std::string& url,
+                         const std::string& arg1, const std::string& arg2,
+                         const std::string& arg3, const std::string& arg4,
+                         const std::string& arg5, const std::string& arg6 )
+{
+    set_command_impl( true, command, url, arg1, arg2, arg3, arg4, arg5, arg6 );
 }
 
 
@@ -275,16 +354,19 @@ void Admin::clock_in()
 //
 // コマンド受付
 //
-// 違うスレッドからもコマンドが来るので、すぐにはコマンドを実行
-// しないで、一旦Dispatcherでメインスレッドにコマンドを渡してからメインスレッドで実行する
+// immediately = false の場合はすぐにコマンドを実行しないで一旦Dispatcherで
+// メインスレッドにコマンドを渡してからメインスレッドで実行する。通常は
+// immediately = false で呼び出して、緊急にコマンドを実行させたい場合は
+// immediately = true とすること。
 //
-void Admin::set_command( const std::string& command, const std::string& url,
+void Admin::set_command_impl( const bool immediately,
+                         const std::string& command, const std::string& url,
                          const std::string& arg1, const std::string& arg2,
                          const std::string& arg3, const std::string& arg4,
                          const std::string& arg5, const std::string& arg6 )
 {
 #ifdef _DEBUG
-    std::cout << "Admin::set_command : " << command << " " << url << std::endl
+    std::cout << "Admin::set_command : immediately = " << immediately <<  " command = " << command << " url = " << url << std::endl
               << arg1 << " " << arg2 << std::endl
               << arg3 << " " << arg4 << std::endl
               << arg5 << " " << arg6 << std::endl;
@@ -299,8 +381,26 @@ void Admin::set_command( const std::string& command, const std::string& url,
     command_arg.arg4 = arg4;
     command_arg.arg5 = arg5;
     command_arg.arg6 = arg6;
-    m_list_command.push_back( command_arg );
-    m_disp.emit();
+
+    if( immediately ){
+
+        m_list_command.push_front( command_arg );
+        exec_command();
+    }
+    else{
+
+        m_list_command.push_back( command_arg );
+        dispatch(); // 一度メインループに戻った後にcallback_dispatch() が呼び戻される
+    }
+}
+
+
+//
+// ディスパッチャのコールバック関数
+//
+void Admin::callback_dispatch()
+{
+    while( m_list_command.size() ) exec_command();
 }
 
 
@@ -329,6 +429,11 @@ void Admin::exec_command()
         restore();
     }
 
+    // 移転などでホストの更新
+    else if( command.command == "update_host" ){
+        update_host( command.url, command.arg1 );
+    }
+
     // viewを開く
     else if( command.command == "open_view" ){
         open_view( command );
@@ -373,8 +478,11 @@ void Admin::exec_command()
     else if( command.command == "update_finish" ){
         update_finish( command.url );
     }
+    else if( command.command == "unlock_views" ){
+        unlock_all_view( command.url );
+    }
     else if( command.command == "close_view" ){
-        if( command.arg1 == "true" ) close_all_view( command.url );
+        if( command.arg1 == "closeall" ) close_all_view( command.url );
         else close_view( command.url );
     }
     else if( command.command == "close_currentview" ){
@@ -385,7 +493,7 @@ void Admin::exec_command()
     }
 
     // フォーカスイン、アウト
-    if( command.command == "focus_current_view" ){
+    else if( command.command == "focus_current_view" ){
         m_focus = true;
         focus_current_view();
     }
@@ -398,6 +506,11 @@ void Admin::exec_command()
         restore_focus();
     }
 
+    // adminクラスを前面に出す
+    else if( command.command == "switch_admin" ){
+        switch_admin();
+    }
+
     // タブに文字をセット、タブ幅調整
     else if( command.command  == "set_tablabel" ){
         set_tablabel( command.url, command.arg1 );
@@ -406,38 +519,29 @@ void Admin::exec_command()
         m_notebook->adjust_tabwidth();
     }
 
-    // タブのアイコンをセット
-    else if( command.command  == "set_tabicon" ){
-        set_tabicon( command.url, command.arg1 );
-    }
-
     // 全てのビューを再描画
-    else if( command.command == "relayout_all" ){
-
-        std::list< SKELETON::View* > list_view = get_list_view();
-        std::list< SKELETON::View* >::iterator it = list_view.begin();
-        for( ; it != list_view.end(); ++it ){
-            SKELETON::View* view = ( *it );
-            if( view ) view->relayout();
-        }
-    }
+    else if( command.command == "relayout_all" ) relayout_all();
 
     // タイトル表示
     // アクティブなviewから依頼が来たらコアに渡す
     else if( command.command == "set_title" ){
-
-        SKELETON::View* view = get_current_view();
-        if( m_focus && view && view->get_url() == command.url )
-            CORE::core_set_command( "set_title", command.url, command.arg1 );
+        set_title( command.url, command.arg1, false );
     }
 
     // ステータス表示
     // アクティブなviewから依頼が来たらコアに渡す
     else if( command.command == "set_status" ){
+        set_status( command.url, command.arg1, false );
+    }
 
-        SKELETON::View* view = get_current_view();
-        if( m_focus && view && view->get_url() == command.url )
-            CORE::core_set_command( "set_status", command.url, command.arg1 );
+    // マウスジェスチャ
+    else if( command.command  == "set_mginfo" ){
+        if( m_win ) m_win->set_mginfo( command.arg1 );
+    }
+
+    // 全タブオートリロード
+    else if( command.command == "reload_all_tabs" ){
+        reload_all_tabs();
     }
 
     // オートリロードのキャンセル
@@ -445,6 +549,49 @@ void Admin::exec_command()
         slot_cancel_reload_all_tabs();
     }
 
+    // タブを隠す
+    else if( command.command == "hide_tabs" ) m_notebook->set_show_tabs( false );
+
+    // window 開け閉じ
+    else if( command.command == "open_window" ){
+        open_window();
+        return;
+    }
+    else if( command.command == "close_window" ){
+        close_window();
+        return;
+    }
+
+    // ツールバー表示切り替え
+    else if( command.command == "toggle_toolbar" ){
+        toggle_toolbar();
+    }
+
+    // タブ表示切り替え
+    else if( command.command == "toggle_tab" ){
+        toggle_tab();
+    }
+
+    // アイコン表示切り替え
+    else if( command.command == "toggle_icon" ){
+        toggle_icon( command.url );
+    }
+
+    // window 開け閉じ可能/不可
+    else if( command.command == "enable_fold_win" ){
+        if( get_jdwin() ) get_jdwin()->set_enable_fold( true );
+    }
+
+    else if( command.command == "disable_fold_win" ){
+        if( get_jdwin() ) get_jdwin()->set_enable_fold( false );
+    }
+
+    // プロパティ表示
+    else if( command.command == "show_current_preferences" ){
+        SKELETON::View* view = get_current_view();
+        if( view ) view->show_preference();
+    }
+
     // 個別のコマンド処理
     else command_local( command );
 }
@@ -467,7 +614,16 @@ void Admin::open_list( const std::string& str_list )
     std::list< std::string >::iterator it = list_url.begin();
     for( ; it != list_url.end(); ++it, waittime += AUTORELOAD_MINSEC ){
 
+        // 各admin別の引数をセット
         COMMAND_ARGS command_arg = get_open_list_args( ( *it ) );
+
+        // 共通の引数をセット
+        command_arg.command = "open_view";
+        command_arg.url = (*it);
+        command_arg.arg1 = "true";   // タブで開く
+        command_arg.arg2 = "false";  // 既に開いているかチェック
+        command_arg.arg3 = "noswitch";  // タブを切り替えない
+
         open_view( command_arg );
 
         // 一番最初のページは普通にオンラインで開く
@@ -479,17 +635,55 @@ void Admin::open_list( const std::string& str_list )
     }
 
     SESSION::set_online( online );
+
+    switch_admin();
     switch_view( *( list_url.begin() ) );
 }
 
 
+//
+// 移転などでviewのホスト名を更新
+//
+void Admin::update_host( const std::string& oldhost, const std::string& newhost )
+{
+#ifdef _DEBUG
+    std::cout << "Admin::update_host " << oldhost << " -> " << newhost << std::endl;
+#endif
+
+    int pages = m_notebook->get_n_pages();
+    if( pages ){
+
+        for( int i = 0; i < pages; ++i ){
+            SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
+            if( view && view->get_url().find( oldhost ) == 0 ) view->update_host( newhost );
+        }
+    }
+}
+
+
+//
+// URLやステータスを更新
+//
+void Admin::update_status( View* view, const bool force )
+{
+    if( view ){
+        set_title( view->get_url(), view->get_title(), force );
+        set_url( view->get_url(), view->url_for_copy(), force );
+        set_status( view->get_url(), view->get_status(), force );
+    }
+}
+
+
 
 //
 // ビューを開く
 //
 // command.arg1: "true" なら新しいtabを開く, "right" ならアクティブなtabの右に、"left"なら左に開く
 // command.arg2: "true" なら既にurlを開いているかチェックしない
-// command.arg3: モード。"auto"なら表示されていればリロードせずに切替え、されていなければ新しいタブで開いてロード
+// command.arg3: モード
+//   arg3 == "auto"なら表示されていればリロードせずに切替え、されていなければ新しいタブで開いてロード(スレ番号ジャンプなどで使用)
+//   arg3 == "noswitch"ならタブを切り替えない(連続して開くときに使用)
+//   arg3 == "lock" なら開いてロックする
 //
 // その他のargは各ビュー別の設定
 //
@@ -501,28 +695,31 @@ void Admin::open_view( const COMMAND_ARGS& command )
     SKELETON::View* view;
     SKELETON::View* current_view = get_current_view();
 
-    // 現在のviewのフォーカスを外し、列幅保存
-    if( current_view ) {
-        current_view->focus_out();
-    }
+    if( current_view ) current_view->focus_out();
 
     // urlを既に開いていたら表示してリロード
     if( ! ( command.arg2 == "true" ) ){
         view = get_view( command.url );
         if( view ){
+
+            if( ! ( command.arg3 == "noswitch" ) ){
             
-            int page = m_notebook->page_num( *view );
+                int page = m_notebook->page_num( *view );
 #ifdef _DEBUG
-            std::cout << "page = " << page << std::endl;
+                std::cout << "page = " << page << std::endl;
 #endif        
-            set_current_page( page );
-            switch_admin();
+                set_current_page( page );
+                switch_admin();
+            }
 
             // オートモードは切り替えのみ
             if( command.arg3 == "auto" ) return;
 
+            // ロック
+            if( command.arg3 == "lock" ) lock( m_notebook->page_num( *view ) );
+
             view->show_view();
-            focus_current_view();
+
             return;
         }
     }
@@ -534,6 +731,7 @@ void Admin::open_view( const COMMAND_ARGS& command )
     int page = m_notebook->get_current_page();
     bool open_tab = (  page == -1 || command.arg1 == "true" || command.arg1 == "right" || command.arg1 == "left"
                        || command.arg3 == "auto" // オートモードの時もタブで開く
+                       || is_locked( page )
         );
 
     // タブで表示
@@ -564,11 +762,17 @@ void Admin::open_view( const COMMAND_ARGS& command )
         if( current_view ) delete current_view;
     }
 
-    switch_admin();
+    m_notebook->show_all();
     view->show();
     view->show_view();
-    set_current_page( m_notebook->page_num( *view ) );
-    focus_current_view();
+
+    if( ! ( command.arg3 == "noswitch" ) ){
+        switch_admin();
+        set_current_page( m_notebook->page_num( *view ) );
+    }
+
+    // ロック
+    if( command.arg3 == "lock" ) lock( m_notebook->page_num( *view ) );
 }
 
 
@@ -724,6 +928,8 @@ void Admin::close_view( SKELETON::View* view )
     int page = m_notebook->page_num( *view );
     int current_page = m_notebook->get_current_page();
 
+    if( is_locked( page ) ) return;
+
     // もし現在表示中のビューを消すときは予めひとつ右のビューにスイッチしておく
     // そうしないと左のビューを一度表示してしまうので遅くなる
     if( page == current_page ){
@@ -740,7 +946,7 @@ void Admin::close_view( SKELETON::View* view )
 #endif
 
     // 全てのビューが無くなったらコアに知らせる
-    if( m_notebook->get_n_pages() == 0 ){
+    if( empty() ){
 #ifdef _DEBUG
         std::cout << "empty\n";
 #endif
@@ -750,6 +956,26 @@ void Admin::close_view( SKELETON::View* view )
 
 
 
+//
+// url を含むビューを全てアンロック
+//
+void Admin::unlock_all_view( const std::string& url )
+{
+#ifdef _DEBUG
+    std::cout << "Admin::unlock_all_view : " << url << std::endl;
+#endif
+
+    std::list< View* > list_view = get_list_view( url );
+
+    std::list< View* >::iterator it = list_view.begin();
+    for( ; it != list_view.end(); ++it ){
+
+        SKELETON::View* view = ( *it );
+        if( view && view->is_locked() ) view->unlock();
+    }
+}
+
+
 //
 // url を含むビューを全て閉じる
 //
@@ -827,6 +1053,63 @@ void Admin::update_finish( const std::string& url )
 }
 
 
+//
+// タイトル表示
+//
+void Admin::set_title( const std::string& url, const std::string& title, const bool force )
+{
+    if( m_win ) m_win->set_title( "JD - " + title );
+    else{
+
+        SKELETON::View* view = get_current_view();
+        if( view ){
+
+            // アクティブなviewからコマンドが来たら表示する
+            if( force || ( m_focus && view->get_url() == url ) ) CORE::core_set_command( "set_title", url, title );
+        }
+    }
+}
+
+
+//
+// URLバーにアドレス表示
+//
+void Admin::set_url( const std::string& url, const std::string& url_show, const bool force )
+{
+    if( m_win ){}
+    else{
+
+        SKELETON::View* view = get_current_view();
+        if( view ){
+
+            // アクティブなviewからコマンドが来たら表示する
+            if( force || ( m_focus && view->get_url() == url ) ) CORE::core_set_command( "set_url", url_show );
+        }
+    }
+}
+
+
+//
+// ステータス表示
+//
+void Admin::set_status( const std::string& url, const std::string& stat, const bool force )
+{
+    if( m_win ) m_win->set_status( stat );
+    else{
+        
+        SKELETON::View* view = get_current_view();
+        if( view ){
+            
+            // アクティブなviewからコマンドが来たら表示する
+            if( force || ( m_focus && view->get_url() == url ) ){
+                CORE::core_set_command( "set_status", url, stat );
+                CORE::core_set_command( "set_mginfo", "", "" );
+            }
+        }
+    }
+}
+
+
 //
 // フォーカスする
 //
@@ -837,13 +1120,13 @@ void Admin::focus_view( int page )
 #ifdef _DEBUG
     std::cout << "Admin::focus_view : " << m_url << " page = " << page << std::endl;
 #endif
+
+    if( m_win ) m_win->focus_in();
     
     SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( page ) );
     if( view ) {
         view->focus_view();
-        CORE::core_set_command( "set_title", "", view->get_title() );
-        CORE::core_set_command( "set_url", view->url_for_copy() );
-        CORE::core_set_command( "set_status", "", view->get_status() );
+        update_status( view, false );
     }
 }
 
@@ -854,6 +1137,8 @@ void Admin::focus_view( int page )
 //
 void Admin::focus_current_view()
 {
+    if( ! m_focus ) return;
+
 #ifdef _DEBUG
     std::cout << "Admin::focus_current_view : " << m_url << std::endl;
 #endif
@@ -892,6 +1177,9 @@ void Admin::focus_out()
     std::cout << "Admin::focus_out : " << m_url << std::endl;
 #endif
 
+    // ウィンドウ表示の時、ビューが隠れないようにフォーカスアウトする前に transient 指定をしておく
+    if( get_jdwin() ) get_jdwin()->set_transient( true );
+
     SKELETON::View* view = get_current_view();
     if( view ) view->focus_out();
     m_notebook->focus_out();
@@ -914,6 +1202,79 @@ void Admin::set_tablabel( const std::string& url, const std::string& str_label )
 
 
 
+//
+// 再レイアウト実行
+//
+void Admin::relayout_all()
+{
+    std::list< SKELETON::View* > list_view = get_list_view();
+    std::list< SKELETON::View* >::iterator it = list_view.begin();
+    for( ; it != list_view.end(); ++it ){
+        SKELETON::View* view = ( *it );
+        if( view ) view->relayout();
+    }
+}
+
+
+//
+// ツールバー表示切り替え
+//
+void Admin::toggle_toolbar()
+{
+    std::list< SKELETON::View* > list_view = get_list_view();
+    std::list< SKELETON::View* >::iterator it = list_view.begin();
+    for( ; it != list_view.end(); ++it ){
+        SKELETON::View* view = ( *it );
+        if( view ) view->toggle_toolbar();
+    }
+}
+
+
+//
+// タブ表示切り替え
+//
+void Admin::toggle_tab()
+{
+    if( m_notebook->get_show_tabs() ) m_notebook->set_show_tabs( false );
+    else m_notebook->set_show_tabs( true );
+}
+
+
+//
+// アイコン表示切り替え
+//
+void Admin::toggle_icon( const std::string& url )
+{
+    SKELETON::View* view = get_view( url );
+    if( view ){
+
+        std::string iconname = "default";
+
+        // まだロード中
+        if( view->is_loading() ) iconname = "loading";
+
+        // オートリロードモードでロード待ち
+        else if( view->get_autoreload_mode() != AUTORELOAD_NOT ) iconname = "loading_stop";
+
+        // 更新あり   
+        else if( view->is_updated() ){
+
+            // タブがアクティブの時は通常アイコンを表示
+            if( get_notebook()->page_num( *view ) == get_notebook()->get_current_page() ) iconname = "default";
+            else iconname = "updated";
+        }
+
+        // 更新チェック済み
+        else if( view->is_check_update() ) iconname = "update";
+
+        // 古い
+        else if( view->is_old() ) iconname = "old";
+
+        int id = view->get_icon( iconname );
+        get_notebook()->set_tabicon( iconname, get_notebook()->page_num( *view ), id );
+    }
+}
+
 
 //
 // オートリロードのモード設定
@@ -935,9 +1296,7 @@ bool Admin::set_autoreload_mode( const std::string& url, int mode, int sec )
         // モード設定が成功したらアイコン変更
         if( view->get_autoreload_mode() == mode ){
 
-            if( mode != AUTORELOAD_NOT ) set_tabicon( view->get_url(), "loading_stop" );
-            else set_tabicon( view->get_url(), "default" );
-
+            toggle_icon( view->get_url() );
             return true;
         }
     }
@@ -950,19 +1309,14 @@ bool Admin::set_autoreload_mode( const std::string& url, int mode, int sec )
 //
 // ビュークラス取得
 //
-// use_find が true なら == の代わりに findを使う
-//
-View* Admin::get_view( const std::string& url, bool use_find )
+View* Admin::get_view( const std::string& url )
 {
     int pages = m_notebook->get_n_pages();
     if( pages ){
 
         for( int i = 0; i < pages; ++i ){
             SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
-            if( view ){
-                if( view->get_url() == url ) return view;
-                else if( use_find && view->get_url().find ( url ) != std::string::npos ) return view;
-            }
+            if( view && view->get_url() == url ) return view;
         }
     }
     
@@ -1051,6 +1405,16 @@ int Admin::get_current_page()
 }
 
 
+//
+// 現在表示されているページのURL
+//
+std::string Admin::get_current_url()
+{
+    SKELETON::View* view = get_current_view();
+    if( ! view ) return std::string();
+    return view->get_url();
+}
+
 
 //
 // notebookのタブのページが切り替わったら呼ばれるslot
@@ -1061,17 +1425,35 @@ void Admin::slot_switch_page( GtkNotebookPage*, guint page )
     std::cout << "Admin::slot_switch_page : " << m_url << " page = " << page << std::endl;
 #endif
 
-    // タブのアイコンを通常に戻す
+    // タブのアイコンを通常に戻して再描画
     SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( page ) );
     if( view ){
 #ifdef _DEBUG
         std::cout << "url = " << view->get_url() << std::endl;
 #endif
-        set_tabicon( view->get_url(), "switch_page" );
-    }
+        toggle_icon( view->get_url() );
 
-    // coreにページが切り替わったことを知らせて、core経由でviewをフォーカスする
-    CORE::core_set_command( "switch_page", m_url );
+        view->redraw_view();
+        if( m_focus ){
+            update_status( view, false );
+            focus_current_view();
+        }
+
+        CORE::core_set_command( "page_switched", m_url, view->get_url() );
+    }
+}
+
+
+//
+// タブをクリック
+//
+void Admin::slot_tab_click( int page )
+{
+#ifdef _DEBUG
+    std::cout << "Admin::slot_tab_click " << page << std::endl;
+#endif
+
+    set_current_page( page );
 }
 
 
@@ -1109,10 +1491,31 @@ void Admin::slot_tab_reload( int page )
 //
 void Admin::slot_tab_menu( int page, int x, int y )
 {
+    if( ! m_ui_manager ) return;
+
 #ifdef _DEBUG
     std::cout << "Admin::slot_tab_menu " << page << std::endl;
 #endif
 
+    Glib::RefPtr< Gtk::Action > act;
+    m_clicked_page = -1; // メニューのactive状態を変えたときにslot関数が呼び出されるのをキャンセル
+
+    // ロック
+    act = m_action_group->get_action( "LockTab" );
+    if( page >= 0 && act ){
+
+        Glib::RefPtr< Gtk::ToggleAction > tact = Glib::RefPtr< Gtk::ToggleAction >::cast_dynamic( act ); 
+        if( is_locked( page ) ) tact->set_active( true );
+        else tact->set_active( false );
+    }
+
+    // 閉じる
+    act = m_action_group->get_action( "Quit" );
+    if( act ){
+        if( is_locked( page ) ) act->set_sensitive( false );
+        else act->set_sensitive( true );
+    }
+
     m_clicked_page = page;
 
     Gtk::Menu* popupmenu = dynamic_cast< Gtk::Menu* >( m_ui_manager->get_widget( "/popup_menu" ) );
@@ -1157,6 +1560,8 @@ void Admin::slot_tab_menu( int page, int x, int y )
 //
 void Admin::slot_close_tab()
 {
+    if( m_clicked_page < 0 ) return;
+
 #ifdef _DEBUG
     std::cout << "Admin::slot_close_tab " << m_clicked_page << std::endl;
 #endif
@@ -1166,6 +1571,18 @@ void Admin::slot_close_tab()
 }
 
 
+//
+// ロック
+//
+void Admin::slot_lock()
+{
+    if( m_clicked_page < 0 ) return;
+
+    if( is_locked( m_clicked_page ) ) unlock( m_clicked_page );
+    else lock( m_clicked_page );
+}
+
+
 //
 // 右クリックメニューの他を閉じる
 //
@@ -1240,9 +1657,59 @@ void Admin::slot_close_all_tabs()
 }
 
 
+//
+// 右クリックメニューの全てのタブの更新チェック
+//
+void Admin::slot_check_update_all_tabs()
+{
+    check_update_all_tabs( m_clicked_page );
+
+    CORE::get_checkupdate_manager()->run( false );
+}
+
 
 //
-// 右クリックメニューの全てを更新
+// 右クリックメニューの全てのタブの更新チェックと再読み込み
+//
+void Admin::slot_check_update_reload_all_tabs()
+{
+    check_update_all_tabs( m_clicked_page );
+
+    CORE::get_checkupdate_manager()->run( true );
+}
+
+
+//
+// from_page から全てのタブを更新チェック
+//
+// この後で CORE::get_checkupdate_manager()->run() すること
+//
+void Admin::check_update_all_tabs( const int from_page )
+{
+#ifdef _DEBUG
+    std::cout << "Admin::check_update_all_tabs from = " << from_page << std::endl;
+#endif
+
+    if( ! SESSION::is_online() ) return;
+
+    int pages = m_notebook->get_n_pages();
+
+    // クリックしたタブから右側
+    for( int i = from_page ; i < pages; ++i ){
+        SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
+        if( view && view->get_enable_autoreload() ) CORE::get_checkupdate_manager()->push_back( view->get_url() );
+    }
+
+    // クリックしたタブから左側
+    for( int i = 0 ; i < from_page; ++i ){
+        SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
+        if( view && view->get_enable_autoreload() ) CORE::get_checkupdate_manager()->push_back( view->get_url() );
+    }
+}
+
+
+//
+// 右クリックメニューの全ての再読み込み
 //
 void Admin::slot_reload_all_tabs()
 {
@@ -1250,13 +1717,35 @@ void Admin::slot_reload_all_tabs()
     std::cout << "Admin::slot_reload_all_tabs " << m_clicked_page << std::endl;
 #endif
 
+    reload_all_tabs( m_clicked_page );
+}
+
+
+//
+// 開いているタブから全てのタブを再読み込み
+//
+void Admin::reload_all_tabs()
+{
+    reload_all_tabs( m_notebook->get_current_page() );
+}
+
+
+//
+// from_page から全てのタブを再読み込み
+//
+void Admin::reload_all_tabs( const int from_page )
+{
+#ifdef _DEBUG
+    std::cout << "Admin::reload_all_tabs from = " << from_page << std::endl;
+#endif
+
     if( ! SESSION::is_online() ) return;
 
     int waittime = 0;
     int pages = m_notebook->get_n_pages();
 
     // クリックしたタブから右側
-    for( int i = m_clicked_page ; i < pages; ++i ){
+    for( int i = from_page ; i < pages; ++i ){
         SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
         if( view ){
             if( set_autoreload_mode( view->get_url(), AUTORELOAD_ONCE, waittime ) ) waittime += AUTORELOAD_MINSEC;
@@ -1264,7 +1753,7 @@ void Admin::slot_reload_all_tabs()
     }
 
     // クリックしたタブから左側
-    for( int i = 0 ; i < m_clicked_page; ++i ){
+    for( int i = 0 ; i < from_page; ++i ){
         SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
         if( view ){
             if( set_autoreload_mode( view->get_url(), AUTORELOAD_ONCE, waittime ) ) waittime += AUTORELOAD_MINSEC;
@@ -1282,6 +1771,8 @@ void Admin::slot_cancel_reload_all_tabs()
         SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
         if( view ) set_autoreload_mode( view->get_url(), AUTORELOAD_NOT, 0 );
     }
+
+    CORE::get_checkupdate_manager()->stop();
 }
 
 
@@ -1321,3 +1812,45 @@ void Admin::slot_copy_title_url()
     
     COPYCLIP( str );
 }
+
+
+// ページがロックされているかリストで取得
+std::list< bool > Admin::get_locked()
+{
+    std::list< bool > locked;
+    
+    int pages = m_notebook->get_n_pages();
+    if( pages ){
+        for( int i = 0; i < pages; ++i ) locked.push_back( is_locked( i ) );
+    }
+
+    return locked;
+}
+
+// タブのロック/アンロック
+const bool Admin::is_locked( const int page )
+{
+    SKELETON::View* view =  dynamic_cast< View* >( m_notebook->get_nth_page( page ) );
+    if( view ) return view->is_locked();
+
+    return false;
+}
+
+void Admin::lock( const int page )
+{
+    SKELETON::View* view =  dynamic_cast< View* >( m_notebook->get_nth_page( page ) );
+    if( view ) return view->lock();
+}
+
+void Admin::unlock( const int page )
+{
+    SKELETON::View* view =  dynamic_cast< View* >( m_notebook->get_nth_page( page ) );
+    if( view ) return view->unlock();
+}
+
+// プロパティ表示
+void Admin::show_preference()
+{
+    SKELETON::View* view =  dynamic_cast< View* >( m_notebook->get_nth_page( m_clicked_page ) );
+    if( view ) view->show_preference();
+}
